/* Accounts.c generated by valac 0.56.19, the Vala compiler
 * generated from Accounts.vala, do not modify */

#include <adwaita.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include <pango/pango.h>
#include <glib/gi18n-lib.h>
#include <gee.h>
#include <libsoup/soup.h>
#include <float.h>
#include <math.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_VIEWS_ADMIN_PAGE_TYPE_BASE (tuba_views_admin_page_base_get_type ())
#define TUBA_VIEWS_ADMIN_PAGE_BASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_ADMIN_PAGE_TYPE_BASE, TubaViewsAdminPageBase))
#define TUBA_VIEWS_ADMIN_PAGE_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_ADMIN_PAGE_TYPE_BASE, TubaViewsAdminPageBaseClass))
#define TUBA_VIEWS_ADMIN_PAGE_IS_BASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_ADMIN_PAGE_TYPE_BASE))
#define TUBA_VIEWS_ADMIN_PAGE_IS_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_ADMIN_PAGE_TYPE_BASE))
#define TUBA_VIEWS_ADMIN_PAGE_BASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_ADMIN_PAGE_TYPE_BASE, TubaViewsAdminPageBaseClass))

typedef struct _TubaViewsAdminPageBase TubaViewsAdminPageBase;
typedef struct _TubaViewsAdminPageBaseClass TubaViewsAdminPageBaseClass;
typedef struct _TubaViewsAdminPageBasePrivate TubaViewsAdminPageBasePrivate;

#define TUBA_VIEWS_ADMIN_PAGE_TYPE_ACCOUNTS (tuba_views_admin_page_accounts_get_type ())
#define TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_ADMIN_PAGE_TYPE_ACCOUNTS, TubaViewsAdminPageAccounts))
#define TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_ADMIN_PAGE_TYPE_ACCOUNTS, TubaViewsAdminPageAccountsClass))
#define TUBA_VIEWS_ADMIN_PAGE_IS_ACCOUNTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_ADMIN_PAGE_TYPE_ACCOUNTS))
#define TUBA_VIEWS_ADMIN_PAGE_IS_ACCOUNTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_ADMIN_PAGE_TYPE_ACCOUNTS))
#define TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_ADMIN_PAGE_TYPE_ACCOUNTS, TubaViewsAdminPageAccountsClass))

typedef struct _TubaViewsAdminPageAccounts TubaViewsAdminPageAccounts;
typedef struct _TubaViewsAdminPageAccountsClass TubaViewsAdminPageAccountsClass;
typedef struct _TubaViewsAdminPageAccountsPrivate TubaViewsAdminPageAccountsPrivate;

#define TUBA_VIEWS_ADMIN_TIMELINE_TYPE_PAGINATION_TIMELINE (tuba_views_admin_timeline_pagination_timeline_get_type ())
#define TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_ADMIN_TIMELINE_TYPE_PAGINATION_TIMELINE, TubaViewsAdminTimelinePaginationTimeline))
#define TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_ADMIN_TIMELINE_TYPE_PAGINATION_TIMELINE, TubaViewsAdminTimelinePaginationTimelineClass))
#define TUBA_VIEWS_ADMIN_TIMELINE_IS_PAGINATION_TIMELINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_ADMIN_TIMELINE_TYPE_PAGINATION_TIMELINE))
#define TUBA_VIEWS_ADMIN_TIMELINE_IS_PAGINATION_TIMELINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_ADMIN_TIMELINE_TYPE_PAGINATION_TIMELINE))
#define TUBA_VIEWS_ADMIN_TIMELINE_PAGINATION_TIMELINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_ADMIN_TIMELINE_TYPE_PAGINATION_TIMELINE, TubaViewsAdminTimelinePaginationTimelineClass))

typedef struct _TubaViewsAdminTimelinePaginationTimeline TubaViewsAdminTimelinePaginationTimeline;
typedef struct _TubaViewsAdminTimelinePaginationTimelineClass TubaViewsAdminTimelinePaginationTimelineClass;

#define TUBA_VIEWS_ADMIN_TIMELINE_TYPE_ACCOUNTS (tuba_views_admin_timeline_accounts_get_type ())
#define TUBA_VIEWS_ADMIN_TIMELINE_ACCOUNTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_ADMIN_TIMELINE_TYPE_ACCOUNTS, TubaViewsAdminTimelineAccounts))
#define TUBA_VIEWS_ADMIN_TIMELINE_ACCOUNTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_ADMIN_TIMELINE_TYPE_ACCOUNTS, TubaViewsAdminTimelineAccountsClass))
#define TUBA_VIEWS_ADMIN_TIMELINE_IS_ACCOUNTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_ADMIN_TIMELINE_TYPE_ACCOUNTS))
#define TUBA_VIEWS_ADMIN_TIMELINE_IS_ACCOUNTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_ADMIN_TIMELINE_TYPE_ACCOUNTS))
#define TUBA_VIEWS_ADMIN_TIMELINE_ACCOUNTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_ADMIN_TIMELINE_TYPE_ACCOUNTS, TubaViewsAdminTimelineAccountsClass))

typedef struct _TubaViewsAdminTimelineAccounts TubaViewsAdminTimelineAccounts;
typedef struct _TubaViewsAdminTimelineAccountsClass TubaViewsAdminTimelineAccountsClass;
enum  {
	TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_0_PROPERTY,
	TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_NUM_PROPERTIES
};
static GParamSpec* tuba_views_admin_page_accounts_properties[TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

#define TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_TYPE_DROP_DOWN_STRING_ENTRY (tuba_views_admin_page_accounts_drop_down_string_entry_get_type ())
#define TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_DROP_DOWN_STRING_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_TYPE_DROP_DOWN_STRING_ENTRY, TubaViewsAdminPageAccountsDropDownStringEntry))
#define TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_DROP_DOWN_STRING_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_TYPE_DROP_DOWN_STRING_ENTRY, TubaViewsAdminPageAccountsDropDownStringEntryClass))
#define TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_IS_DROP_DOWN_STRING_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_TYPE_DROP_DOWN_STRING_ENTRY))
#define TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_IS_DROP_DOWN_STRING_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_TYPE_DROP_DOWN_STRING_ENTRY))
#define TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_DROP_DOWN_STRING_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_TYPE_DROP_DOWN_STRING_ENTRY, TubaViewsAdminPageAccountsDropDownStringEntryClass))

typedef struct _TubaViewsAdminPageAccountsDropDownStringEntry TubaViewsAdminPageAccountsDropDownStringEntry;
typedef struct _TubaViewsAdminPageAccountsDropDownStringEntryClass TubaViewsAdminPageAccountsDropDownStringEntryClass;

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;

#define TUBA_API_ADMIN_TYPE_ACCOUNT (tuba_api_admin_account_get_type ())
#define TUBA_API_ADMIN_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_ADMIN_TYPE_ACCOUNT, TubaAPIAdminAccount))
#define TUBA_API_ADMIN_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_ADMIN_TYPE_ACCOUNT, TubaAPIAdminAccountClass))
#define TUBA_API_ADMIN_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_ADMIN_TYPE_ACCOUNT))
#define TUBA_API_ADMIN_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_ADMIN_TYPE_ACCOUNT))
#define TUBA_API_ADMIN_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_ADMIN_TYPE_ACCOUNT, TubaAPIAdminAccountClass))

typedef struct _TubaAPIAdminAccount TubaAPIAdminAccount;
typedef struct _TubaAPIAdminAccountClass TubaAPIAdminAccountClass;

#define TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_TYPE_ACCOUNT_DIALOG (tuba_views_admin_page_accounts_account_dialog_get_type ())
#define TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_ACCOUNT_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_TYPE_ACCOUNT_DIALOG, TubaViewsAdminPageAccountsAccountDialog))
#define TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_ACCOUNT_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_TYPE_ACCOUNT_DIALOG, TubaViewsAdminPageAccountsAccountDialogClass))
#define TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_IS_ACCOUNT_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_TYPE_ACCOUNT_DIALOG))
#define TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_IS_ACCOUNT_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_TYPE_ACCOUNT_DIALOG))
#define TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_ACCOUNT_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_TYPE_ACCOUNT_DIALOG, TubaViewsAdminPageAccountsAccountDialogClass))

typedef struct _TubaViewsAdminPageAccountsAccountDialog TubaViewsAdminPageAccountsAccountDialog;
typedef struct _TubaViewsAdminPageAccountsAccountDialogClass TubaViewsAdminPageAccountsAccountDialogClass;
typedef struct _TubaViewsAdminPageAccountsDropDownStringEntryPrivate TubaViewsAdminPageAccountsDropDownStringEntryPrivate;
enum  {
	TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_DROP_DOWN_STRING_ENTRY_0_PROPERTY,
	TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_DROP_DOWN_STRING_ENTRY_API_PROPERTY,
	TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_DROP_DOWN_STRING_ENTRY_TITLE_PROPERTY,
	TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_DROP_DOWN_STRING_ENTRY_NUM_PROPERTIES
};
static GParamSpec* tuba_views_admin_page_accounts_drop_down_string_entry_properties[TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_DROP_DOWN_STRING_ENTRY_NUM_PROPERTIES];
typedef struct _TubaViewsAdminPageAccountsAccountDialogPrivate TubaViewsAdminPageAccountsAccountDialogPrivate;
enum  {
	TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_ACCOUNT_DIALOG_0_PROPERTY,
	TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_ACCOUNT_DIALOG_NUM_PROPERTIES
};
static GParamSpec* tuba_views_admin_page_accounts_account_dialog_properties[TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_ACCOUNT_DIALOG_NUM_PROPERTIES];

#define TUBA_API_TYPE_ACCOUNT (tuba_api_account_get_type ())
#define TUBA_API_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccount))
#define TUBA_API_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))
#define TUBA_API_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))

typedef struct _TubaAPIAccount TubaAPIAccount;
typedef struct _TubaAPIAccountClass TubaAPIAccountClass;

#define TUBA_WIDGETS_TYPE_ACCOUNT (tuba_widgets_account_get_type ())
#define TUBA_WIDGETS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_ACCOUNT, TubaWidgetsAccount))
#define TUBA_WIDGETS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_ACCOUNT, TubaWidgetsAccountClass))
#define TUBA_WIDGETS_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_ACCOUNT))
#define TUBA_WIDGETS_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_ACCOUNT))
#define TUBA_WIDGETS_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_ACCOUNT, TubaWidgetsAccountClass))

typedef struct _TubaWidgetsAccount TubaWidgetsAccount;
typedef struct _TubaWidgetsAccountClass TubaWidgetsAccountClass;

#define TUBA_TYPE_WIDGETIZABLE (tuba_widgetizable_get_type ())
#define TUBA_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizable))
#define TUBA_IS_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_WIDGETIZABLE))
#define TUBA_WIDGETIZABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizableIface))

typedef struct _TubaWidgetizable TubaWidgetizable;
typedef struct _TubaWidgetizableIface TubaWidgetizableIface;

#define TUBA_TYPE_INSTANCE_ACCOUNT (tuba_instance_account_get_type ())
#define TUBA_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccount))
#define TUBA_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))
#define TUBA_IS_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_IS_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_INSTANCE_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))

typedef struct _TubaInstanceAccount TubaInstanceAccount;
typedef struct _TubaInstanceAccountClass TubaInstanceAccountClass;
#define _g_date_time_unref0(var) ((var == NULL) ? NULL : (var = (g_date_time_unref (var), NULL)))
#define _g_time_zone_unref0(var) ((var == NULL) ? NULL : (var = (g_time_zone_unref (var), NULL)))
#define _g_regex_unref0(var) ((var == NULL) ? NULL : (var = (g_regex_unref (var), NULL)))

#define TUBA_API_TYPE_ACCOUNT_ROLE (tuba_api_account_role_get_type ())
#define TUBA_API_ACCOUNT_ROLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT_ROLE, TubaAPIAccountRole))
#define TUBA_API_ACCOUNT_ROLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT_ROLE, TubaAPIAccountRoleClass))
#define TUBA_API_IS_ACCOUNT_ROLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT_ROLE))
#define TUBA_API_IS_ACCOUNT_ROLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT_ROLE))
#define TUBA_API_ACCOUNT_ROLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT_ROLE, TubaAPIAccountRoleClass))

typedef struct _TubaAPIAccountRole TubaAPIAccountRole;
typedef struct _TubaAPIAccountRoleClass TubaAPIAccountRoleClass;

#define TUBA_API_ADMIN_ACCOUNT_TYPE_IP_ADDRESS (tuba_api_admin_account_ip_address_get_type ())
#define TUBA_API_ADMIN_ACCOUNT_IP_ADDRESS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_ADMIN_ACCOUNT_TYPE_IP_ADDRESS, TubaAPIAdminAccountIPAddress))
#define TUBA_API_ADMIN_ACCOUNT_IP_ADDRESS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_ADMIN_ACCOUNT_TYPE_IP_ADDRESS, TubaAPIAdminAccountIPAddressClass))
#define TUBA_API_ADMIN_ACCOUNT_IS_IP_ADDRESS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_ADMIN_ACCOUNT_TYPE_IP_ADDRESS))
#define TUBA_API_ADMIN_ACCOUNT_IS_IP_ADDRESS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_ADMIN_ACCOUNT_TYPE_IP_ADDRESS))
#define TUBA_API_ADMIN_ACCOUNT_IP_ADDRESS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_ADMIN_ACCOUNT_TYPE_IP_ADDRESS, TubaAPIAdminAccountIPAddressClass))

typedef struct _TubaAPIAdminAccountIPAddress TubaAPIAdminAccountIPAddress;
typedef struct _TubaAPIAdminAccountIPAddressClass TubaAPIAdminAccountIPAddressClass;

#define TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_ACCOUNT_DIALOG_TYPE_UNDO_ROW (tuba_views_admin_page_accounts_account_dialog_undo_row_get_type ())
#define TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_ACCOUNT_DIALOG_UNDO_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_ACCOUNT_DIALOG_TYPE_UNDO_ROW, TubaViewsAdminPageAccountsAccountDialogUndoRow))
#define TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_ACCOUNT_DIALOG_UNDO_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_ACCOUNT_DIALOG_TYPE_UNDO_ROW, TubaViewsAdminPageAccountsAccountDialogUndoRowClass))
#define TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_ACCOUNT_DIALOG_IS_UNDO_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_ACCOUNT_DIALOG_TYPE_UNDO_ROW))
#define TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_ACCOUNT_DIALOG_IS_UNDO_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_ACCOUNT_DIALOG_TYPE_UNDO_ROW))
#define TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_ACCOUNT_DIALOG_UNDO_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_ACCOUNT_DIALOG_TYPE_UNDO_ROW, TubaViewsAdminPageAccountsAccountDialogUndoRowClass))

typedef struct _TubaViewsAdminPageAccountsAccountDialogUndoRow TubaViewsAdminPageAccountsAccountDialogUndoRow;
typedef struct _TubaViewsAdminPageAccountsAccountDialogUndoRowClass TubaViewsAdminPageAccountsAccountDialogUndoRowClass;

#define TUBA_DIALOGS_ADMIN_TYPE_BASE (tuba_dialogs_admin_base_get_type ())
#define TUBA_DIALOGS_ADMIN_BASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_DIALOGS_ADMIN_TYPE_BASE, TubaDialogsAdminBase))
#define TUBA_DIALOGS_ADMIN_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_DIALOGS_ADMIN_TYPE_BASE, TubaDialogsAdminBaseClass))
#define TUBA_DIALOGS_ADMIN_IS_BASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_DIALOGS_ADMIN_TYPE_BASE))
#define TUBA_DIALOGS_ADMIN_IS_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_DIALOGS_ADMIN_TYPE_BASE))
#define TUBA_DIALOGS_ADMIN_BASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_DIALOGS_ADMIN_TYPE_BASE, TubaDialogsAdminBaseClass))

typedef struct _TubaDialogsAdminBase TubaDialogsAdminBase;
typedef struct _TubaDialogsAdminBaseClass TubaDialogsAdminBaseClass;

#define TUBA_DIALOGS_ADMIN_TYPE_TAKE_ACTION (tuba_dialogs_admin_take_action_get_type ())
#define TUBA_DIALOGS_ADMIN_TAKE_ACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_DIALOGS_ADMIN_TYPE_TAKE_ACTION, TubaDialogsAdminTakeAction))
#define TUBA_DIALOGS_ADMIN_TAKE_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_DIALOGS_ADMIN_TYPE_TAKE_ACTION, TubaDialogsAdminTakeActionClass))
#define TUBA_DIALOGS_ADMIN_IS_TAKE_ACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_DIALOGS_ADMIN_TYPE_TAKE_ACTION))
#define TUBA_DIALOGS_ADMIN_IS_TAKE_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_DIALOGS_ADMIN_TYPE_TAKE_ACTION))
#define TUBA_DIALOGS_ADMIN_TAKE_ACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_DIALOGS_ADMIN_TYPE_TAKE_ACTION, TubaDialogsAdminTakeActionClass))

typedef struct _TubaDialogsAdminTakeAction TubaDialogsAdminTakeAction;
typedef struct _TubaDialogsAdminTakeActionClass TubaDialogsAdminTakeActionClass;

#define TUBA_TYPE_REQUEST_V2 (tuba_request_v2_get_type ())
#define TUBA_REQUEST_V2(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_REQUEST_V2, TubaRequestV2))
#define TUBA_REQUEST_V2_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_REQUEST_V2, TubaRequestV2Class))
#define TUBA_IS_REQUEST_V2(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_REQUEST_V2))
#define TUBA_IS_REQUEST_V2_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_REQUEST_V2))
#define TUBA_REQUEST_V2_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_REQUEST_V2, TubaRequestV2Class))

typedef struct _TubaRequestV2 TubaRequestV2;
typedef struct _TubaRequestV2Class TubaRequestV2Class;
typedef enum  {
	TUBA_REQUEST_V2_METHOD_GET,
	TUBA_REQUEST_V2_METHOD_POST,
	TUBA_REQUEST_V2_METHOD_PUT,
	TUBA_REQUEST_V2_METHOD_DELETE,
	TUBA_REQUEST_V2_METHOD_PATCH
} TubaRequestV2Method;

#define TUBA_REQUEST_V2_TYPE_METHOD (tuba_request_v2_method_get_type ())

#define TUBA_TYPE_ACCOUNT_STORE (tuba_account_store_get_type ())
#define TUBA_ACCOUNT_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStore))
#define TUBA_ACCOUNT_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStoreClass))
#define TUBA_IS_ACCOUNT_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ACCOUNT_STORE))
#define TUBA_IS_ACCOUNT_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ACCOUNT_STORE))
#define TUBA_ACCOUNT_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStoreClass))

typedef struct _TubaAccountStore TubaAccountStore;
typedef struct _TubaAccountStoreClass TubaAccountStoreClass;

#define TUBA_TYPE_OOPSIE (tuba_oopsie_get_type ())
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _TubaViewsAdminPageAccountsAccountDialogOnApproveRealData TubaViewsAdminPageAccountsAccountDialogOnApproveRealData;
typedef struct _TubaViewsAdminPageAccountsAccountDialogOnRejectRealData TubaViewsAdminPageAccountsAccountDialogOnRejectRealData;
typedef struct _TubaViewsAdminPageAccountsAccountDialogUndoRowPrivate TubaViewsAdminPageAccountsAccountDialogUndoRowPrivate;
enum  {
	TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_ACCOUNT_DIALOG_UNDO_ROW_0_PROPERTY,
	TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_ACCOUNT_DIALOG_UNDO_ROW_NUM_PROPERTIES
};
static GParamSpec* tuba_views_admin_page_accounts_account_dialog_undo_row_properties[TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_ACCOUNT_DIALOG_UNDO_ROW_NUM_PROPERTIES];
typedef struct _TubaViewsAdminPageAccountsAccountDialogUndoRowOnUndoRealData TubaViewsAdminPageAccountsAccountDialogUndoRowOnUndoRealData;
enum  {
	TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_ACCOUNT_DIALOG_UNDO_ROW_ON_ERROR_SIGNAL,
	TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_ACCOUNT_DIALOG_UNDO_ROW_UNDONE_SIGNAL,
	TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_ACCOUNT_DIALOG_UNDO_ROW_NUM_SIGNALS
};
static guint tuba_views_admin_page_accounts_account_dialog_undo_row_signals[TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_ACCOUNT_DIALOG_UNDO_ROW_NUM_SIGNALS] = {0};
enum  {
	TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_ACCOUNT_DIALOG_REFRESH_SIGNAL,
	TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_ACCOUNT_DIALOG_NUM_SIGNALS
};
static guint tuba_views_admin_page_accounts_account_dialog_signals[TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_ACCOUNT_DIALOG_NUM_SIGNALS] = {0};
#define __vala_GValue_free0(var) ((var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL)))
#define _adw_breakpoint_condition_free0(var) ((var == NULL) ? NULL : (var = (adw_breakpoint_condition_free (var), NULL)))

struct _TubaViewsAdminPageBase {
	AdwNavigationPage parent_instance;
	TubaViewsAdminPageBasePrivate * priv;
	AdwHeaderBar* headerbar;
	AdwToolbarView* toolbar_view;
};

struct _TubaViewsAdminPageBaseClass {
	AdwNavigationPageClass parent_class;
	void (*add_to_page) (TubaViewsAdminPageBase* self, AdwPreferencesGroup* group);
};

struct _TubaViewsAdminPageAccounts {
	TubaViewsAdminPageBase parent_instance;
	TubaViewsAdminPageAccountsPrivate * priv;
};

struct _TubaViewsAdminPageAccountsClass {
	TubaViewsAdminPageBaseClass parent_class;
};

struct _TubaViewsAdminPageAccountsPrivate {
	GtkEntry* username_entry;
	GtkEntry* display_name_entry;
	GtkEntry* ip_entry;
	GtkEntry* email_entry;
	TubaViewsAdminTimelineAccounts* pagination_timeline;
	GtkRevealer* revealer;
	GtkToggleButton* search_button;
	GtkDropDown* location_dropdown;
	GtkDropDown* moderation_dropdown;
};

struct _TubaViewsAdminPageAccountsDropDownStringEntry {
	GObject parent_instance;
	TubaViewsAdminPageAccountsDropDownStringEntryPrivate * priv;
};

struct _TubaViewsAdminPageAccountsDropDownStringEntryClass {
	GObjectClass parent_class;
};

struct _TubaViewsAdminPageAccountsDropDownStringEntryPrivate {
	gchar* _api;
	gchar* _title;
};

struct _TubaViewsAdminPageAccountsAccountDialog {
	AdwDialog parent_instance;
	TubaViewsAdminPageAccountsAccountDialogPrivate * priv;
};

struct _TubaViewsAdminPageAccountsAccountDialogClass {
	AdwDialogClass parent_class;
};

struct _TubaViewsAdminPageAccountsAccountDialogPrivate {
	AdwPreferencesPage* page;
	AdwToastOverlay* toast_overlay;
	gchar* account_id;
	gchar* account_handle;
	AdwActionRow* approval_row;
	gboolean should_refresh;
};

struct _TubaWidgetizableIface {
	GTypeInterface parent_iface;
	GtkWidget* (*to_widget) (TubaWidgetizable* self);
	void (*open) (TubaWidgetizable* self);
	void (*resolve_open) (TubaWidgetizable* self, TubaInstanceAccount* account);
};

typedef enum  {
	TUBA_OOPSIE_USER,
	TUBA_OOPSIE_PARSING,
	TUBA_OOPSIE_INSTANCE,
	TUBA_OOPSIE_INTERNAL,
	TUBA_OOPSIE_HTTP_401 = 401,
	TUBA_OOPSIE_HTTP_403 = 403,
	TUBA_OOPSIE_HTTP_404 = 404,
	TUBA_OOPSIE_HTTP_410 = 410,
	TUBA_OOPSIE_HTTP_422 = 422,
	TUBA_OOPSIE_HTTP_429 = 429,
	TUBA_OOPSIE_HTTP_500 = 500,
	TUBA_OOPSIE_HTTP_503 = 503
} TubaOopsie;
#define TUBA_OOPSIE tuba_oopsie_quark ()

struct _TubaViewsAdminPageAccountsAccountDialogOnApproveRealData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	TubaViewsAdminPageAccountsAccountDialog* self;
	AdwAlertDialog* dlg;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	AdwAlertDialog* _tmp3_;
	AdwAlertDialog* _tmp4_;
	AdwAlertDialog* _tmp5_;
	AdwAlertDialog* _tmp6_;
	AdwAlertDialog* _tmp7_;
	AdwAlertDialog* _tmp8_;
	AdwAlertDialog* _tmp9_;
	const gchar* _tmp10_;
	AdwActionRow* _tmp11_;
	TubaRequestV2* req;
	const gchar* _tmp12_;
	const gchar* _tmp13_;
	gchar* _tmp14_;
	gchar* _tmp15_;
	TubaAccountStore* _tmp16_;
	TubaInstanceAccount* _tmp17_;
	TubaInstanceAccount* _tmp18_;
	TubaInstanceAccount* _tmp19_;
	TubaRequestV2* _tmp20_;
	TubaRequestV2* _tmp21_;
	TubaRequestV2* _tmp22_;
	GInputStream* _tmp23_;
	GInputStream* _tmp24_;
	AdwActionRow* _tmp25_;
	GError* e;
	AdwActionRow* _tmp26_;
	GError* _tmp27_;
	gchar* _tmp28_;
	gchar* _tmp29_;
	GError* _tmp30_;
	const gchar* _tmp31_;
	const gchar* _tmp32_;
	gchar* _tmp33_;
	gchar* _tmp34_;
	GError* _tmp35_;
	const gchar* _tmp36_;
	GError* _inner_error0_;
};

struct _TubaViewsAdminPageAccountsAccountDialogOnRejectRealData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	TubaViewsAdminPageAccountsAccountDialog* self;
	AdwAlertDialog* dlg;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	AdwAlertDialog* _tmp3_;
	AdwAlertDialog* _tmp4_;
	AdwAlertDialog* _tmp5_;
	AdwAlertDialog* _tmp6_;
	AdwAlertDialog* _tmp7_;
	AdwAlertDialog* _tmp8_;
	AdwAlertDialog* _tmp9_;
	const gchar* _tmp10_;
	AdwActionRow* _tmp11_;
	TubaRequestV2* req;
	const gchar* _tmp12_;
	const gchar* _tmp13_;
	gchar* _tmp14_;
	gchar* _tmp15_;
	TubaAccountStore* _tmp16_;
	TubaInstanceAccount* _tmp17_;
	TubaInstanceAccount* _tmp18_;
	TubaInstanceAccount* _tmp19_;
	TubaRequestV2* _tmp20_;
	TubaRequestV2* _tmp21_;
	TubaRequestV2* _tmp22_;
	GInputStream* _tmp23_;
	GInputStream* _tmp24_;
	AdwActionRow* _tmp25_;
	GError* e;
	AdwActionRow* _tmp26_;
	GError* _tmp27_;
	gchar* _tmp28_;
	gchar* _tmp29_;
	GError* _tmp30_;
	const gchar* _tmp31_;
	const gchar* _tmp32_;
	gchar* _tmp33_;
	gchar* _tmp34_;
	GError* _tmp35_;
	const gchar* _tmp36_;
	GError* _inner_error0_;
};

struct _TubaViewsAdminPageAccountsAccountDialogUndoRow {
	AdwActionRow parent_instance;
	TubaViewsAdminPageAccountsAccountDialogUndoRowPrivate * priv;
};

struct _TubaViewsAdminPageAccountsAccountDialogUndoRowClass {
	AdwActionRowClass parent_class;
};

struct _TubaViewsAdminPageAccountsAccountDialogUndoRowPrivate {
	gchar* account_id;
	gchar* endpoint;
	GtkButton* action_button;
};

struct _TubaViewsAdminPageAccountsAccountDialogUndoRowOnUndoRealData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	TubaViewsAdminPageAccountsAccountDialogUndoRow* self;
	AdwAlertDialog* dlg;
	AdwAlertDialog* _tmp0_;
	AdwAlertDialog* _tmp1_;
	AdwAlertDialog* _tmp2_;
	AdwAlertDialog* _tmp3_;
	AdwAlertDialog* _tmp4_;
	AdwAlertDialog* _tmp5_;
	const gchar* _tmp6_;
	GtkButton* _tmp7_;
	TubaRequestV2* req;
	const gchar* _tmp8_;
	const gchar* _tmp9_;
	const gchar* _tmp10_;
	const gchar* _tmp11_;
	gchar* _tmp12_;
	gchar* _tmp13_;
	TubaAccountStore* _tmp14_;
	TubaInstanceAccount* _tmp15_;
	TubaInstanceAccount* _tmp16_;
	TubaInstanceAccount* _tmp17_;
	TubaRequestV2* _tmp18_;
	TubaRequestV2* _tmp19_;
	TubaRequestV2* _tmp20_;
	GInputStream* _tmp21_;
	GInputStream* _tmp22_;
	GError* e;
	GtkButton* _tmp23_;
	const gchar* _tmp24_;
	const gchar* _tmp25_;
	GError* _tmp26_;
	gchar* _tmp27_;
	gchar* _tmp28_;
	GError* _tmp29_;
	const gchar* _tmp30_;
	const gchar* _tmp31_;
	gchar* _tmp32_;
	gchar* _tmp33_;
	GError* _tmp34_;
	const gchar* _tmp35_;
	GError* _inner_error0_;
};

static gint TubaViewsAdminPageAccounts_private_offset;
static gpointer tuba_views_admin_page_accounts_parent_class = NULL;
static gint TubaViewsAdminPageAccountsDropDownStringEntry_private_offset;
static gpointer tuba_views_admin_page_accounts_drop_down_string_entry_parent_class = NULL;
static gint TubaViewsAdminPageAccountsAccountDialog_private_offset;
static gpointer tuba_views_admin_page_accounts_account_dialog_parent_class = NULL;
VALA_EXTERN TubaAccountStore* tuba_accounts;
static gint TubaViewsAdminPageAccountsAccountDialogUndoRow_private_offset;
static gpointer tuba_views_admin_page_accounts_account_dialog_undo_row_parent_class = NULL;

VALA_EXTERN GType tuba_views_admin_page_base_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsAdminPageBase, g_object_unref)
VALA_EXTERN GType tuba_views_admin_page_accounts_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsAdminPageAccounts, g_object_unref)
VALA_EXTERN GType tuba_views_admin_timeline_pagination_timeline_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsAdminTimelinePaginationTimeline, g_object_unref)
VALA_EXTERN GType tuba_views_admin_timeline_accounts_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsAdminTimelineAccounts, g_object_unref)
static void tuba_views_admin_page_accounts_on_search_button_toggle (TubaViewsAdminPageAccounts* self);
static void tuba_views_admin_page_accounts_on_search (TubaViewsAdminPageAccounts* self);
static void _vala_array_add122 (gchar** * array,
                         gint* length,
                         gint* size,
                         gchar* value);
static void _vala_array_add123 (gchar** * array,
                         gint* length,
                         gint* size,
                         gchar* value);
static void _vala_array_add124 (gchar** * array,
                         gint* length,
                         gint* size,
                         gchar* value);
static void _vala_array_add125 (gchar** * array,
                         gint* length,
                         gint* size,
                         gchar* value);
static GType tuba_views_admin_page_accounts_drop_down_string_entry_get_type (void) G_GNUC_CONST  G_GNUC_UNUSED ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsAdminPageAccountsDropDownStringEntry, g_object_unref)
static const gchar* tuba_views_admin_page_accounts_drop_down_string_entry_get_api (TubaViewsAdminPageAccountsDropDownStringEntry* self);
static void _vala_array_add126 (gchar** * array,
                         gint* length,
                         gint* size,
                         gchar* value);
static void _vala_array_add127 (gchar** * array,
                         gint* length,
                         gint* size,
                         gchar* value);
VALA_EXTERN void tuba_views_admin_timeline_pagination_timeline_reset (TubaViewsAdminTimelinePaginationTimeline* self,
                                                          const gchar* new_url);
static void tuba_views_admin_page_accounts_refresh (TubaViewsAdminPageAccounts* self);
VALA_EXTERN void tuba_views_admin_timeline_pagination_timeline_request (TubaViewsAdminTimelinePaginationTimeline* self,
                                                            GAsyncReadyCallback _callback_,
                                                            gpointer _user_data_);
VALA_EXTERN void tuba_views_admin_timeline_pagination_timeline_request_finish (TubaViewsAdminTimelinePaginationTimeline* self,
                                                                   GAsyncResult* _res_);
static void tuba_views_admin_page_accounts_dropdown_signal (TubaViewsAdminPageAccounts* self,
                                                     GObject* item);
static const gchar* tuba_views_admin_page_accounts_drop_down_string_entry_get_title (TubaViewsAdminPageAccountsDropDownStringEntry* self);
VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN GType tuba_api_admin_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAdminAccount, g_object_unref)
static void tuba_views_admin_page_accounts_show_account_dialog (TubaViewsAdminPageAccounts* self,
                                                         TubaAPIAdminAccount* account);
static GType tuba_views_admin_page_accounts_account_dialog_get_type (void) G_GNUC_CONST  G_GNUC_UNUSED ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsAdminPageAccountsAccountDialog, g_object_unref)
static TubaViewsAdminPageAccountsAccountDialog* tuba_views_admin_page_accounts_account_dialog_new (TubaAPIAdminAccount* account);
static TubaViewsAdminPageAccountsAccountDialog* tuba_views_admin_page_accounts_account_dialog_construct (GType object_type,
                                                                                                  TubaAPIAdminAccount* account);
static void _tuba_views_admin_page_accounts_refresh_tuba_views_admin_page_accounts_account_dialog_refresh (TubaViewsAdminPageAccountsAccountDialog* _sender,
                                                                                                    gpointer self);
VALA_EXTERN TubaViewsAdminPageAccounts* tuba_views_admin_page_accounts_new (void);
VALA_EXTERN TubaViewsAdminPageAccounts* tuba_views_admin_page_accounts_construct (GType object_type);
VALA_EXTERN TubaViewsAdminPageBase* tuba_views_admin_page_base_new (void);
VALA_EXTERN TubaViewsAdminPageBase* tuba_views_admin_page_base_construct (GType object_type);
static TubaViewsAdminPageAccountsDropDownStringEntry* tuba_views_admin_page_accounts_drop_down_string_entry_new (const gchar* api,
                                                                                                          const gchar* title);
static TubaViewsAdminPageAccountsDropDownStringEntry* tuba_views_admin_page_accounts_drop_down_string_entry_construct (GType object_type,
                                                                                                                const gchar* api,
                                                                                                                const gchar* title);
static void tuba_views_admin_page_accounts_drop_down_string_entry_set_api (TubaViewsAdminPageAccountsDropDownStringEntry* self,
                                                                    const gchar* value);
static void tuba_views_admin_page_accounts_drop_down_string_entry_set_title (TubaViewsAdminPageAccountsDropDownStringEntry* self,
                                                                      const gchar* value);
static void tuba_views_admin_page_accounts_drop_down_string_entry_finalize (GObject * obj);
static GType tuba_views_admin_page_accounts_drop_down_string_entry_get_type_once (void);
static void _vala_tuba_views_admin_page_accounts_drop_down_string_entry_get_property (GObject * object,
                                                                               guint property_id,
                                                                               GValue * value,
                                                                               GParamSpec * pspec);
static void _vala_tuba_views_admin_page_accounts_drop_down_string_entry_set_property (GObject * object,
                                                                               guint property_id,
                                                                               const GValue * value,
                                                                               GParamSpec * pspec);
VALA_EXTERN GType tuba_api_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccount, g_object_unref)
VALA_EXTERN TubaAPIAccount* tuba_api_admin_account_get_account (TubaAPIAdminAccount* self);
VALA_EXTERN const gchar* tuba_api_account_get_id (TubaAPIAccount* self);
VALA_EXTERN gchar* tuba_api_account_get_full_handle (TubaAPIAccount* self);
VALA_EXTERN GType tuba_widgets_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsAccount, g_object_unref)
VALA_EXTERN GType tuba_instance_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaInstanceAccount, g_object_unref)
VALA_EXTERN GType tuba_widgetizable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetizable, g_object_unref)
VALA_EXTERN GtkWidget* tuba_widgetizable_to_widget (TubaWidgetizable* self);
VALA_EXTERN void tuba_widgets_account_set_disable_profile_open (TubaWidgetsAccount* self,
                                                    gboolean value);
VALA_EXTERN const gchar* tuba_api_account_get_created_at (TubaAPIAccount* self);
VALA_EXTERN GType tuba_api_account_role_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccountRole, g_object_unref)
VALA_EXTERN TubaAPIAccountRole* tuba_api_admin_account_get_role (TubaAPIAdminAccount* self);
VALA_EXTERN const gchar* tuba_api_account_role_get_name (TubaAPIAccountRole* self);
VALA_EXTERN const gchar* tuba_api_admin_account_get_email (TubaAPIAdminAccount* self);
VALA_EXTERN gboolean tuba_api_admin_account_get_confirmed (TubaAPIAdminAccount* self);
VALA_EXTERN GType tuba_api_admin_account_ip_address_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAdminAccountIPAddress, g_object_unref)
VALA_EXTERN GeeArrayList* tuba_api_admin_account_get_ips (TubaAPIAdminAccount* self);
VALA_EXTERN const gchar* tuba_api_admin_account_ip_address_get_ip (TubaAPIAdminAccountIPAddress* self);
static void _vala_array_add128 (gchar** * array,
                         gint* length,
                         gint* size,
                         gchar* value);
VALA_EXTERN gboolean tuba_api_admin_account_get_approved (TubaAPIAdminAccount* self);
VALA_EXTERN const gchar* tuba_api_admin_account_get_invite_request (TubaAPIAdminAccount* self);
static void tuba_views_admin_page_accounts_account_dialog_on_approve (TubaViewsAdminPageAccountsAccountDialog* self);
static void _tuba_views_admin_page_accounts_account_dialog_on_approve_gtk_button_clicked (GtkButton* _sender,
                                                                                   gpointer self);
static void tuba_views_admin_page_accounts_account_dialog_on_reject (TubaViewsAdminPageAccountsAccountDialog* self);
static void _tuba_views_admin_page_accounts_account_dialog_on_reject_gtk_button_clicked (GtkButton* _sender,
                                                                                  gpointer self);
VALA_EXTERN gboolean tuba_api_admin_account_get_suspended (TubaAPIAdminAccount* self);
static GType tuba_views_admin_page_accounts_account_dialog_undo_row_get_type (void) G_GNUC_CONST  G_GNUC_UNUSED ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsAdminPageAccountsAccountDialogUndoRow, g_object_unref)
static TubaViewsAdminPageAccountsAccountDialogUndoRow* tuba_views_admin_page_accounts_account_dialog_undo_row_new (const gchar* title,
                                                                                                            const gchar* account_id,
                                                                                                            const gchar* endpoint);
static TubaViewsAdminPageAccountsAccountDialogUndoRow* tuba_views_admin_page_accounts_account_dialog_undo_row_construct (GType object_type,
                                                                                                                  const gchar* title,
                                                                                                                  const gchar* account_id,
                                                                                                                  const gchar* endpoint);
static void tuba_views_admin_page_accounts_account_dialog_add_toast (TubaViewsAdminPageAccountsAccountDialog* self,
                                                              const gchar* content,
                                                              guint timeout);
static void _tuba_views_admin_page_accounts_account_dialog_add_toast_tuba_views_admin_page_accounts_account_dialog_undo_row_on_error (TubaViewsAdminPageAccountsAccountDialogUndoRow* _sender,
                                                                                                                               const gchar* message,
                                                                                                                               guint timeout,
                                                                                                                               gpointer self);
static void tuba_views_admin_page_accounts_account_dialog_mark_for_refresh (TubaViewsAdminPageAccountsAccountDialog* self);
static void _tuba_views_admin_page_accounts_account_dialog_mark_for_refresh_tuba_views_admin_page_accounts_account_dialog_undo_row_undone (TubaViewsAdminPageAccountsAccountDialogUndoRow* _sender,
                                                                                                                                    gpointer self);
VALA_EXTERN gboolean tuba_api_admin_account_get_silenced (TubaAPIAdminAccount* self);
VALA_EXTERN gboolean tuba_api_admin_account_get_disabled (TubaAPIAdminAccount* self);
static void tuba_views_admin_page_accounts_account_dialog_show_take_action_dialog (TubaViewsAdminPageAccountsAccountDialog* self);
VALA_EXTERN GType tuba_dialogs_admin_base_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaDialogsAdminBase, g_object_unref)
VALA_EXTERN GType tuba_dialogs_admin_take_action_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaDialogsAdminTakeAction, g_object_unref)
VALA_EXTERN TubaDialogsAdminTakeAction* tuba_dialogs_admin_take_action_new (const gchar* account_id,
                                                                const gchar* account_handle,
                                                                const gchar* report_id);
VALA_EXTERN TubaDialogsAdminTakeAction* tuba_dialogs_admin_take_action_construct (GType object_type,
                                                                      const gchar* account_id,
                                                                      const gchar* account_handle,
                                                                      const gchar* report_id);
static void tuba_views_admin_page_accounts_account_dialog_on_took_action (TubaViewsAdminPageAccountsAccountDialog* self);
static void _tuba_views_admin_page_accounts_account_dialog_on_took_action_tuba_dialogs_admin_take_action_took_action (TubaDialogsAdminTakeAction* _sender,
                                                                                                               gpointer self);
static void tuba_views_admin_page_accounts_account_dialog_on_close (TubaViewsAdminPageAccountsAccountDialog* self);
static void tuba_views_admin_page_accounts_account_dialog_on_approve_real (TubaViewsAdminPageAccountsAccountDialog* self,
                                                                    GAsyncReadyCallback _callback_,
                                                                    gpointer _user_data_);
static void tuba_views_admin_page_accounts_account_dialog_on_approve_real_finish (TubaViewsAdminPageAccountsAccountDialog* self,
                                                                           GAsyncResult* _res_);
static void tuba_views_admin_page_accounts_account_dialog_on_approve_real_data_free (gpointer _data);
static gboolean tuba_views_admin_page_accounts_account_dialog_on_approve_real_co (TubaViewsAdminPageAccountsAccountDialogOnApproveRealData* _data_);
static void tuba_views_admin_page_accounts_account_dialog_on_approve_real_ready (GObject* source_object,
                                                                          GAsyncResult* _res_,
                                                                          gpointer _user_data_);
VALA_EXTERN GType tuba_request_v2_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaRequestV2, g_object_unref)
VALA_EXTERN GType tuba_request_v2_method_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType tuba_account_store_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAccountStore, g_object_unref)
VALA_EXTERN TubaInstanceAccount* tuba_account_store_get_active (TubaAccountStore* self);
VALA_EXTERN TubaRequestV2* tuba_request_v2_new (const gchar* url,
                                    TubaRequestV2Method method);
VALA_EXTERN TubaRequestV2* tuba_request_v2_construct (GType object_type,
                                          const gchar* url,
                                          TubaRequestV2Method method);
VALA_EXTERN void tuba_request_v2_set_account (TubaRequestV2* self,
                                  TubaInstanceAccount* value);
VALA_EXTERN void tuba_request_v2_exec (TubaRequestV2* self,
                           GAsyncReadyCallback _callback_,
                           gpointer _user_data_);
VALA_EXTERN GQuark tuba_oopsie_quark (void);
VALA_EXTERN GType tuba_oopsie_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GInputStream* tuba_request_v2_exec_finish (TubaRequestV2* self,
                                           GAsyncResult* _res_,
                                           SoupMessageHeaders** response_headers,
                                           GError** error);
static void tuba_views_admin_page_accounts_account_dialog_on_reject_real (TubaViewsAdminPageAccountsAccountDialog* self,
                                                                   GAsyncReadyCallback _callback_,
                                                                   gpointer _user_data_);
static void tuba_views_admin_page_accounts_account_dialog_on_reject_real_finish (TubaViewsAdminPageAccountsAccountDialog* self,
                                                                          GAsyncResult* _res_);
static void tuba_views_admin_page_accounts_account_dialog_on_reject_real_data_free (gpointer _data);
static gboolean tuba_views_admin_page_accounts_account_dialog_on_reject_real_co (TubaViewsAdminPageAccountsAccountDialogOnRejectRealData* _data_);
static void tuba_views_admin_page_accounts_account_dialog_on_reject_real_ready (GObject* source_object,
                                                                         GAsyncResult* _res_,
                                                                         gpointer _user_data_);
static void tuba_views_admin_page_accounts_account_dialog_undo_row_on_undo (TubaViewsAdminPageAccountsAccountDialogUndoRow* self);
static void _tuba_views_admin_page_accounts_account_dialog_undo_row_on_undo_gtk_button_clicked (GtkButton* _sender,
                                                                                         gpointer self);
static void tuba_views_admin_page_accounts_account_dialog_undo_row_on_undo_real (TubaViewsAdminPageAccountsAccountDialogUndoRow* self,
                                                                          GAsyncReadyCallback _callback_,
                                                                          gpointer _user_data_);
static void tuba_views_admin_page_accounts_account_dialog_undo_row_on_undo_real_finish (TubaViewsAdminPageAccountsAccountDialogUndoRow* self,
                                                                                 GAsyncResult* _res_);
static void tuba_views_admin_page_accounts_account_dialog_undo_row_on_undo_real_data_free (gpointer _data);
static gboolean tuba_views_admin_page_accounts_account_dialog_undo_row_on_undo_real_co (TubaViewsAdminPageAccountsAccountDialogUndoRowOnUndoRealData* _data_);
static void tuba_views_admin_page_accounts_account_dialog_undo_row_on_undo_real_ready (GObject* source_object,
                                                                                GAsyncResult* _res_,
                                                                                gpointer _user_data_);
static void g_cclosure_user_marshal_VOID__STRING_UINT (GClosure * closure,
                                                GValue * return_value,
                                                guint n_param_values,
                                                const GValue * param_values,
                                                gpointer invocation_hint,
                                                gpointer marshal_data);
static void tuba_views_admin_page_accounts_account_dialog_undo_row_finalize (GObject * obj);
static GType tuba_views_admin_page_accounts_account_dialog_undo_row_get_type_once (void);
static GObject * tuba_views_admin_page_accounts_account_dialog_constructor (GType type,
                                                                     guint n_construct_properties,
                                                                     GObjectConstructParam * construct_properties);
static void _tuba_views_admin_page_accounts_account_dialog_show_take_action_dialog_gtk_button_clicked (GtkButton* _sender,
                                                                                                gpointer self);
static void _tuba_views_admin_page_accounts_account_dialog_on_close_gtk_button_clicked (GtkButton* _sender,
                                                                                 gpointer self);
static void tuba_views_admin_page_accounts_account_dialog_finalize (GObject * obj);
static GType tuba_views_admin_page_accounts_account_dialog_get_type_once (void);
static GObject * tuba_views_admin_page_accounts_constructor (GType type,
                                                      guint n_construct_properties,
                                                      GObjectConstructParam * construct_properties);
static void _tuba_views_admin_page_accounts_on_search_button_toggle_gtk_toggle_button_toggled (GtkToggleButton* _sender,
                                                                                        gpointer self);
static void _vala_GValue_free (GValue* self);
static void _tuba_views_admin_page_accounts_dropdown_signal_gtk_signal_list_item_factory_bind (GtkSignalListItemFactory* _sender,
                                                                                        GObject* object,
                                                                                        gpointer self);
static void _tuba_views_admin_page_accounts_on_search_g_object_notify (GObject* _sender,
                                                                GParamSpec* pspec,
                                                                gpointer self);
static void _tuba_views_admin_page_accounts_on_search_gtk_entry_activate (GtkEntry* _sender,
                                                                   gpointer self);
VALA_EXTERN TubaViewsAdminTimelineAccounts* tuba_views_admin_timeline_accounts_new (void);
VALA_EXTERN TubaViewsAdminTimelineAccounts* tuba_views_admin_timeline_accounts_construct (GType object_type);
static void _tuba_views_admin_page_accounts_show_account_dialog_tuba_views_admin_timeline_accounts_on_open_account (TubaViewsAdminTimelineAccounts* _sender,
                                                                                                             TubaAPIAdminAccount* account,
                                                                                                             gpointer self);
VALA_EXTERN void tuba_views_admin_page_base_on_error (TubaViewsAdminPageBase* self,
                                          gint code,
                                          const gchar* message);
static void _tuba_views_admin_page_base_on_error_tuba_views_admin_timeline_pagination_timeline_on_error (TubaViewsAdminTimelinePaginationTimeline* _sender,
                                                                                                  gint code,
                                                                                                  const gchar* message,
                                                                                                  gpointer self);
VALA_EXTERN void tuba_views_admin_page_base_set_page (TubaViewsAdminPageBase* self,
                                          GtkWidget* value);
static void tuba_views_admin_page_accounts_finalize (GObject * obj);
static GType tuba_views_admin_page_accounts_get_type_once (void);
static void _vala_array_destroy (gpointer array,
                          gssize array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gssize array_length,
                       GDestroyNotify destroy_func);

static inline gpointer
tuba_views_admin_page_accounts_get_instance_private (TubaViewsAdminPageAccounts* self)
{
	return G_STRUCT_MEMBER_P (self, TubaViewsAdminPageAccounts_private_offset);
}

static void
tuba_views_admin_page_accounts_on_search_button_toggle (TubaViewsAdminPageAccounts* self)
{
	GtkRevealer* _tmp0_;
	GtkToggleButton* _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->revealer;
	_tmp1_ = self->priv->search_button;
	_tmp2_ = gtk_toggle_button_get_active (_tmp1_);
	_tmp3_ = _tmp2_;
	gtk_revealer_set_reveal_child (_tmp0_, _tmp3_);
}

static const gchar*
string_to_string (const gchar* self)
{
	const gchar* result;
	g_return_val_if_fail (self != NULL, NULL);
	result = self;
	return result;
}

static void
_vala_array_add122 (gchar** * array,
                    gint* length,
                    gint* size,
                    gchar* value)
{
	if ((*length) == (*size)) {
		*size = (*size) ? (2 * (*size)) : 4;
		*array = g_renew (gchar*, *array, (*size) + 1);
	}
	(*array)[(*length)++] = value;
	(*array)[*length] = NULL;
}

static void
_vala_array_add123 (gchar** * array,
                    gint* length,
                    gint* size,
                    gchar* value)
{
	if ((*length) == (*size)) {
		*size = (*size) ? (2 * (*size)) : 4;
		*array = g_renew (gchar*, *array, (*size) + 1);
	}
	(*array)[(*length)++] = value;
	(*array)[*length] = NULL;
}

static void
_vala_array_add124 (gchar** * array,
                    gint* length,
                    gint* size,
                    gchar* value)
{
	if ((*length) == (*size)) {
		*size = (*size) ? (2 * (*size)) : 4;
		*array = g_renew (gchar*, *array, (*size) + 1);
	}
	(*array)[(*length)++] = value;
	(*array)[*length] = NULL;
}

static void
_vala_array_add125 (gchar** * array,
                    gint* length,
                    gint* size,
                    gchar* value)
{
	if ((*length) == (*size)) {
		*size = (*size) ? (2 * (*size)) : 4;
		*array = g_renew (gchar*, *array, (*size) + 1);
	}
	(*array)[(*length)++] = value;
	(*array)[*length] = NULL;
}

static void
_vala_array_add126 (gchar** * array,
                    gint* length,
                    gint* size,
                    gchar* value)
{
	if ((*length) == (*size)) {
		*size = (*size) ? (2 * (*size)) : 4;
		*array = g_renew (gchar*, *array, (*size) + 1);
	}
	(*array)[(*length)++] = value;
	(*array)[*length] = NULL;
}

static void
_vala_array_add127 (gchar** * array,
                    gint* length,
                    gint* size,
                    gchar* value)
{
	if ((*length) == (*size)) {
		*size = (*size) ? (2 * (*size)) : 4;
		*array = g_renew (gchar*, *array, (*size) + 1);
	}
	(*array)[(*length)++] = value;
	(*array)[*length] = NULL;
}

static gchar*
_vala_g_strjoinv (const gchar* separator,
                  gchar** str_array,
                  gint str_array_length1)
{
	gboolean _tmp0_ = FALSE;
	gchar* result;
	if (separator == NULL) {
		separator = "";
	}
	if (str_array != NULL) {
		gboolean _tmp1_ = FALSE;
		if (str_array_length1 > 0) {
			_tmp1_ = TRUE;
		} else {
			gboolean _tmp2_ = FALSE;
			if (str_array_length1 == -1) {
				const gchar* _tmp3_;
				_tmp3_ = str_array[0];
				_tmp2_ = _tmp3_ != NULL;
			} else {
				_tmp2_ = FALSE;
			}
			_tmp1_ = _tmp2_;
		}
		_tmp0_ = _tmp1_;
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		gint i = 0;
		gsize len = 0UL;
		gint _tmp16_;
		gint _tmp17_;
		const gchar* res = NULL;
		void* _tmp18_;
		const gchar* _tmp19_ = NULL;
		const gchar* _tmp20_;
		void* ptr = NULL;
		const gchar* _tmp22_;
		void* _tmp23_;
		const gchar* _tmp33_;
		len = (gsize) 1;
		{
			gboolean _tmp4_ = FALSE;
			i = 0;
			_tmp4_ = TRUE;
			while (TRUE) {
				gboolean _tmp6_ = FALSE;
				gboolean _tmp7_ = FALSE;
				gint _tmp10_ = 0;
				const gchar* _tmp11_;
				if (!_tmp4_) {
					gint _tmp5_;
					_tmp5_ = i;
					i = _tmp5_ + 1;
				}
				_tmp4_ = FALSE;
				if (str_array_length1 != -1) {
					_tmp7_ = i < str_array_length1;
				} else {
					_tmp7_ = FALSE;
				}
				if (_tmp7_) {
					_tmp6_ = TRUE;
				} else {
					gboolean _tmp8_ = FALSE;
					if (str_array_length1 == -1) {
						const gchar* _tmp9_;
						_tmp9_ = str_array[i];
						_tmp8_ = _tmp9_ != NULL;
					} else {
						_tmp8_ = FALSE;
					}
					_tmp6_ = _tmp8_;
				}
				if (!_tmp6_) {
					break;
				}
				_tmp11_ = str_array[i];
				if (_tmp11_ != NULL) {
					const gchar* _tmp12_;
					gint _tmp13_;
					gint _tmp14_;
					_tmp12_ = str_array[i];
					_tmp13_ = strlen ((const gchar*) _tmp12_);
					_tmp14_ = _tmp13_;
					_tmp10_ = _tmp14_;
				} else {
					_tmp10_ = 0;
				}
				len += (gsize) _tmp10_;
			}
		}
		if (i == 0) {
			gchar* _tmp15_;
			_tmp15_ = g_strdup ("");
			result = _tmp15_;
			return result;
		}
		str_array_length1 = i;
		_tmp16_ = strlen ((const gchar*) separator);
		_tmp17_ = _tmp16_;
		len += (gsize) (_tmp17_ * (i - 1));
		_tmp18_ = g_malloc (len);
		res = _tmp18_;
		_tmp20_ = str_array[0];
		if (_tmp20_ != NULL) {
			const gchar* _tmp21_;
			_tmp21_ = str_array[0];
			_tmp19_ = (const gchar*) _tmp21_;
		} else {
			_tmp19_ = "";
		}
		_tmp22_ = res;
		_tmp23_ = g_stpcpy ((void*) _tmp22_, _tmp19_);
		ptr = _tmp23_;
		{
			gboolean _tmp24_ = FALSE;
			i = 1;
			_tmp24_ = TRUE;
			while (TRUE) {
				void* _tmp26_;
				void* _tmp27_;
				const gchar* _tmp28_ = NULL;
				const gchar* _tmp29_;
				void* _tmp31_;
				void* _tmp32_;
				if (!_tmp24_) {
					gint _tmp25_;
					_tmp25_ = i;
					i = _tmp25_ + 1;
				}
				_tmp24_ = FALSE;
				if (!(i < str_array_length1)) {
					break;
				}
				_tmp26_ = ptr;
				_tmp27_ = g_stpcpy (_tmp26_, (const gchar*) separator);
				ptr = _tmp27_;
				_tmp29_ = str_array[i];
				if (_tmp29_ != NULL) {
					const gchar* _tmp30_;
					_tmp30_ = str_array[i];
					_tmp28_ = (const gchar*) _tmp30_;
				} else {
					_tmp28_ = "";
				}
				_tmp31_ = ptr;
				_tmp32_ = g_stpcpy (_tmp31_, _tmp28_);
				ptr = _tmp32_;
			}
		}
		_tmp33_ = res;
		res = NULL;
		result = (gchar*) _tmp33_;
		return result;
	} else {
		gchar* _tmp34_;
		_tmp34_ = g_strdup ("");
		result = _tmp34_;
		return result;
	}
}

static void
tuba_views_admin_page_accounts_on_search (TubaViewsAdminPageAccounts* self)
{
	gchar** qparams = NULL;
	gchar** _tmp0_;
	gint qparams_length1;
	gint _qparams_size_;
	GtkEntry* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	GtkEntry* _tmp11_;
	const gchar* _tmp12_;
	const gchar* _tmp13_;
	GtkEntry* _tmp21_;
	const gchar* _tmp22_;
	const gchar* _tmp23_;
	GtkEntry* _tmp31_;
	const gchar* _tmp32_;
	const gchar* _tmp33_;
	GtkDropDown* _tmp41_;
	guint _tmp42_;
	guint _tmp43_;
	GtkDropDown* _tmp51_;
	guint _tmp52_;
	guint _tmp53_;
	gchar* _tmp61_ = NULL;
	gchar** _tmp62_;
	gint _tmp62__length1;
	gchar* endpoint = NULL;
	gchar* _tmp69_;
	TubaViewsAdminTimelineAccounts* _tmp70_;
	const gchar* _tmp71_;
	gchar* _tmp72_;
	gchar* _tmp73_;
	g_return_if_fail (self != NULL);
	_tmp0_ = g_new0 (gchar*, 0 + 1);
	qparams = _tmp0_;
	qparams_length1 = 0;
	_qparams_size_ = qparams_length1;
	_tmp1_ = self->priv->username_entry;
	_tmp2_ = gtk_editable_get_text ((GtkEditable*) _tmp1_);
	_tmp3_ = _tmp2_;
	if (g_strcmp0 (_tmp3_, "") != 0) {
		GtkEntry* _tmp4_;
		const gchar* _tmp5_;
		const gchar* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		const gchar* _tmp9_;
		gchar* _tmp10_;
		_tmp4_ = self->priv->username_entry;
		_tmp5_ = gtk_editable_get_text ((GtkEditable*) _tmp4_);
		_tmp6_ = _tmp5_;
		_tmp7_ = g_uri_escape_string (_tmp6_, NULL, TRUE);
		_tmp8_ = _tmp7_;
		_tmp9_ = string_to_string (_tmp8_);
		_tmp10_ = g_strconcat ("username=", _tmp9_, NULL);
		_vala_array_add122 (&qparams, &qparams_length1, &_qparams_size_, _tmp10_);
		_g_free0 (_tmp8_);
	}
	_tmp11_ = self->priv->display_name_entry;
	_tmp12_ = gtk_editable_get_text ((GtkEditable*) _tmp11_);
	_tmp13_ = _tmp12_;
	if (g_strcmp0 (_tmp13_, "") != 0) {
		GtkEntry* _tmp14_;
		const gchar* _tmp15_;
		const gchar* _tmp16_;
		gchar* _tmp17_;
		gchar* _tmp18_;
		const gchar* _tmp19_;
		gchar* _tmp20_;
		_tmp14_ = self->priv->display_name_entry;
		_tmp15_ = gtk_editable_get_text ((GtkEditable*) _tmp14_);
		_tmp16_ = _tmp15_;
		_tmp17_ = g_uri_escape_string (_tmp16_, NULL, TRUE);
		_tmp18_ = _tmp17_;
		_tmp19_ = string_to_string (_tmp18_);
		_tmp20_ = g_strconcat ("display_name=", _tmp19_, NULL);
		_vala_array_add123 (&qparams, &qparams_length1, &_qparams_size_, _tmp20_);
		_g_free0 (_tmp18_);
	}
	_tmp21_ = self->priv->email_entry;
	_tmp22_ = gtk_editable_get_text ((GtkEditable*) _tmp21_);
	_tmp23_ = _tmp22_;
	if (g_strcmp0 (_tmp23_, "") != 0) {
		GtkEntry* _tmp24_;
		const gchar* _tmp25_;
		const gchar* _tmp26_;
		gchar* _tmp27_;
		gchar* _tmp28_;
		const gchar* _tmp29_;
		gchar* _tmp30_;
		_tmp24_ = self->priv->email_entry;
		_tmp25_ = gtk_editable_get_text ((GtkEditable*) _tmp24_);
		_tmp26_ = _tmp25_;
		_tmp27_ = g_uri_escape_string (_tmp26_, NULL, TRUE);
		_tmp28_ = _tmp27_;
		_tmp29_ = string_to_string (_tmp28_);
		_tmp30_ = g_strconcat ("email=", _tmp29_, NULL);
		_vala_array_add124 (&qparams, &qparams_length1, &_qparams_size_, _tmp30_);
		_g_free0 (_tmp28_);
	}
	_tmp31_ = self->priv->ip_entry;
	_tmp32_ = gtk_editable_get_text ((GtkEditable*) _tmp31_);
	_tmp33_ = _tmp32_;
	if (g_strcmp0 (_tmp33_, "") != 0) {
		GtkEntry* _tmp34_;
		const gchar* _tmp35_;
		const gchar* _tmp36_;
		gchar* _tmp37_;
		gchar* _tmp38_;
		const gchar* _tmp39_;
		gchar* _tmp40_;
		_tmp34_ = self->priv->ip_entry;
		_tmp35_ = gtk_editable_get_text ((GtkEditable*) _tmp34_);
		_tmp36_ = _tmp35_;
		_tmp37_ = g_uri_escape_string (_tmp36_, NULL, TRUE);
		_tmp38_ = _tmp37_;
		_tmp39_ = string_to_string (_tmp38_);
		_tmp40_ = g_strconcat ("ip=", _tmp39_, NULL);
		_vala_array_add125 (&qparams, &qparams_length1, &_qparams_size_, _tmp40_);
		_g_free0 (_tmp38_);
	}
	_tmp41_ = self->priv->location_dropdown;
	_tmp42_ = gtk_drop_down_get_selected (_tmp41_);
	_tmp43_ = _tmp42_;
	if (_tmp43_ > ((guint) 0)) {
		GtkDropDown* _tmp44_;
		GObject* _tmp45_;
		GObject* _tmp46_;
		const gchar* _tmp47_;
		const gchar* _tmp48_;
		const gchar* _tmp49_;
		gchar* _tmp50_;
		_tmp44_ = self->priv->location_dropdown;
		_tmp45_ = gtk_drop_down_get_selected_item (_tmp44_);
		_tmp46_ = _tmp45_;
		_tmp47_ = tuba_views_admin_page_accounts_drop_down_string_entry_get_api (G_TYPE_CHECK_INSTANCE_CAST (_tmp46_, TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_TYPE_DROP_DOWN_STRING_ENTRY, TubaViewsAdminPageAccountsDropDownStringEntry));
		_tmp48_ = _tmp47_;
		_tmp49_ = string_to_string (_tmp48_);
		_tmp50_ = g_strconcat (_tmp49_, "=true", NULL);
		_vala_array_add126 (&qparams, &qparams_length1, &_qparams_size_, _tmp50_);
	}
	_tmp51_ = self->priv->moderation_dropdown;
	_tmp52_ = gtk_drop_down_get_selected (_tmp51_);
	_tmp53_ = _tmp52_;
	if (_tmp53_ > ((guint) 0)) {
		GtkDropDown* _tmp54_;
		GObject* _tmp55_;
		GObject* _tmp56_;
		const gchar* _tmp57_;
		const gchar* _tmp58_;
		const gchar* _tmp59_;
		gchar* _tmp60_;
		_tmp54_ = self->priv->moderation_dropdown;
		_tmp55_ = gtk_drop_down_get_selected_item (_tmp54_);
		_tmp56_ = _tmp55_;
		_tmp57_ = tuba_views_admin_page_accounts_drop_down_string_entry_get_api (G_TYPE_CHECK_INSTANCE_CAST (_tmp56_, TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_TYPE_DROP_DOWN_STRING_ENTRY, TubaViewsAdminPageAccountsDropDownStringEntry));
		_tmp58_ = _tmp57_;
		_tmp59_ = string_to_string (_tmp58_);
		_tmp60_ = g_strconcat (_tmp59_, "=true", NULL);
		_vala_array_add127 (&qparams, &qparams_length1, &_qparams_size_, _tmp60_);
	}
	_tmp62_ = qparams;
	_tmp62__length1 = qparams_length1;
	if (_tmp62__length1 > 0) {
		gchar** _tmp63_;
		gint _tmp63__length1;
		gchar* _tmp64_;
		gchar* _tmp65_;
		const gchar* _tmp66_;
		gchar* _tmp67_;
		_tmp63_ = qparams;
		_tmp63__length1 = qparams_length1;
		_tmp64_ = _vala_g_strjoinv ("&", _tmp63_, (gint) _tmp63__length1);
		_tmp65_ = _tmp64_;
		_tmp66_ = string_to_string (_tmp65_);
		_tmp67_ = g_strconcat ("?", _tmp66_, NULL);
		_g_free0 (_tmp61_);
		_tmp61_ = _tmp67_;
		_g_free0 (_tmp65_);
	} else {
		gchar* _tmp68_;
		_tmp68_ = g_strdup ("");
		_g_free0 (_tmp61_);
		_tmp61_ = _tmp68_;
	}
	_tmp69_ = _tmp61_;
	_tmp61_ = NULL;
	endpoint = _tmp69_;
	_tmp70_ = self->priv->pagination_timeline;
	_tmp71_ = string_to_string (endpoint);
	_tmp72_ = g_strconcat ("/api/v1/admin/accounts", _tmp71_, NULL);
	_tmp73_ = _tmp72_;
	tuba_views_admin_timeline_pagination_timeline_reset ((TubaViewsAdminTimelinePaginationTimeline*) _tmp70_, _tmp73_);
	_g_free0 (_tmp73_);
	_g_free0 (endpoint);
	_g_free0 (_tmp61_);
	qparams = (_vala_array_free (qparams, qparams_length1, (GDestroyNotify) g_free), NULL);
}

static void
tuba_views_admin_page_accounts_refresh (TubaViewsAdminPageAccounts* self)
{
	TubaViewsAdminTimelineAccounts* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->pagination_timeline;
	tuba_views_admin_timeline_pagination_timeline_request ((TubaViewsAdminTimelinePaginationTimeline*) _tmp0_, NULL, NULL);
}

static void
tuba_views_admin_page_accounts_dropdown_signal (TubaViewsAdminPageAccounts* self,
                                                GObject* item)
{
	GObject* _tmp0_;
	GObject* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	GtkLabel* _tmp4_ = NULL;
	GtkLabel* _tmp5_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (item != NULL);
	_tmp0_ = gtk_list_item_get_item (G_TYPE_CHECK_INSTANCE_CAST (item, gtk_list_item_get_type (), GtkListItem));
	_tmp1_ = _tmp0_;
	_tmp2_ = tuba_views_admin_page_accounts_drop_down_string_entry_get_title (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_TYPE_DROP_DOWN_STRING_ENTRY, TubaViewsAdminPageAccountsDropDownStringEntry));
	_tmp3_ = _tmp2_;
	_tmp4_ = (GtkLabel*) gtk_label_new (_tmp3_);
	gtk_label_set_ellipsize (_tmp4_, PANGO_ELLIPSIZE_END);
	g_object_ref_sink (_tmp4_);
	_tmp5_ = _tmp4_;
	gtk_list_item_set_child (G_TYPE_CHECK_INSTANCE_CAST (item, gtk_list_item_get_type (), GtkListItem), (GtkWidget*) _tmp5_);
	_g_object_unref0 (_tmp5_);
}

static void
_tuba_views_admin_page_accounts_refresh_tuba_views_admin_page_accounts_account_dialog_refresh (TubaViewsAdminPageAccountsAccountDialog* _sender,
                                                                                               gpointer self)
{
	tuba_views_admin_page_accounts_refresh ((TubaViewsAdminPageAccounts*) self);
}

static void
tuba_views_admin_page_accounts_show_account_dialog (TubaViewsAdminPageAccounts* self,
                                                    TubaAPIAdminAccount* account)
{
	TubaViewsAdminPageAccountsAccountDialog* dlg = NULL;
	TubaViewsAdminPageAccountsAccountDialog* _tmp0_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (account != NULL);
	_tmp0_ = tuba_views_admin_page_accounts_account_dialog_new (account);
	g_object_ref_sink (_tmp0_);
	dlg = _tmp0_;
	g_signal_connect_object (dlg, "refresh", (GCallback) _tuba_views_admin_page_accounts_refresh_tuba_views_admin_page_accounts_account_dialog_refresh, self, 0);
	adw_dialog_present ((AdwDialog*) dlg, (GtkWidget*) self);
	_g_object_unref0 (dlg);
}

TubaViewsAdminPageAccounts*
tuba_views_admin_page_accounts_construct (GType object_type)
{
	TubaViewsAdminPageAccounts * self = NULL;
	self = (TubaViewsAdminPageAccounts*) tuba_views_admin_page_base_construct (object_type);
	return self;
}

TubaViewsAdminPageAccounts*
tuba_views_admin_page_accounts_new (void)
{
	return tuba_views_admin_page_accounts_construct (TUBA_VIEWS_ADMIN_PAGE_TYPE_ACCOUNTS);
}

static inline gpointer
tuba_views_admin_page_accounts_drop_down_string_entry_get_instance_private (TubaViewsAdminPageAccountsDropDownStringEntry* self)
{
	return G_STRUCT_MEMBER_P (self, TubaViewsAdminPageAccountsDropDownStringEntry_private_offset);
}

static TubaViewsAdminPageAccountsDropDownStringEntry*
tuba_views_admin_page_accounts_drop_down_string_entry_construct (GType object_type,
                                                                 const gchar* api,
                                                                 const gchar* title)
{
	TubaViewsAdminPageAccountsDropDownStringEntry * self = NULL;
	g_return_val_if_fail (api != NULL, NULL);
	g_return_val_if_fail (title != NULL, NULL);
	self = (TubaViewsAdminPageAccountsDropDownStringEntry*) g_object_new (object_type, NULL);
	tuba_views_admin_page_accounts_drop_down_string_entry_set_api (self, api);
	tuba_views_admin_page_accounts_drop_down_string_entry_set_title (self, title);
	return self;
}

static TubaViewsAdminPageAccountsDropDownStringEntry*
tuba_views_admin_page_accounts_drop_down_string_entry_new (const gchar* api,
                                                           const gchar* title)
{
	return tuba_views_admin_page_accounts_drop_down_string_entry_construct (TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_TYPE_DROP_DOWN_STRING_ENTRY, api, title);
}

static const gchar*
tuba_views_admin_page_accounts_drop_down_string_entry_get_api (TubaViewsAdminPageAccountsDropDownStringEntry* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_api;
	result = _tmp0_;
	return result;
}

static void
tuba_views_admin_page_accounts_drop_down_string_entry_set_api (TubaViewsAdminPageAccountsDropDownStringEntry* self,
                                                               const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_views_admin_page_accounts_drop_down_string_entry_get_api (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_api);
		self->priv->_api = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_views_admin_page_accounts_drop_down_string_entry_properties[TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_DROP_DOWN_STRING_ENTRY_API_PROPERTY]);
	}
}

static const gchar*
tuba_views_admin_page_accounts_drop_down_string_entry_get_title (TubaViewsAdminPageAccountsDropDownStringEntry* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_title;
	result = _tmp0_;
	return result;
}

static void
tuba_views_admin_page_accounts_drop_down_string_entry_set_title (TubaViewsAdminPageAccountsDropDownStringEntry* self,
                                                                 const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_views_admin_page_accounts_drop_down_string_entry_get_title (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_title);
		self->priv->_title = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_views_admin_page_accounts_drop_down_string_entry_properties[TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_DROP_DOWN_STRING_ENTRY_TITLE_PROPERTY]);
	}
}

static void
tuba_views_admin_page_accounts_drop_down_string_entry_class_init (TubaViewsAdminPageAccountsDropDownStringEntryClass * klass,
                                                                  gpointer klass_data)
{
	tuba_views_admin_page_accounts_drop_down_string_entry_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaViewsAdminPageAccountsDropDownStringEntry_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_views_admin_page_accounts_drop_down_string_entry_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_views_admin_page_accounts_drop_down_string_entry_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_views_admin_page_accounts_drop_down_string_entry_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_DROP_DOWN_STRING_ENTRY_API_PROPERTY, tuba_views_admin_page_accounts_drop_down_string_entry_properties[TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_DROP_DOWN_STRING_ENTRY_API_PROPERTY] = g_param_spec_string ("api", "api", "api", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_DROP_DOWN_STRING_ENTRY_TITLE_PROPERTY, tuba_views_admin_page_accounts_drop_down_string_entry_properties[TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_DROP_DOWN_STRING_ENTRY_TITLE_PROPERTY] = g_param_spec_string ("title", "title", "title", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_views_admin_page_accounts_drop_down_string_entry_instance_init (TubaViewsAdminPageAccountsDropDownStringEntry * self,
                                                                     gpointer klass)
{
	self->priv = tuba_views_admin_page_accounts_drop_down_string_entry_get_instance_private (self);
}

static void
tuba_views_admin_page_accounts_drop_down_string_entry_finalize (GObject * obj)
{
	TubaViewsAdminPageAccountsDropDownStringEntry * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_TYPE_DROP_DOWN_STRING_ENTRY, TubaViewsAdminPageAccountsDropDownStringEntry);
	_g_free0 (self->priv->_api);
	_g_free0 (self->priv->_title);
	G_OBJECT_CLASS (tuba_views_admin_page_accounts_drop_down_string_entry_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_views_admin_page_accounts_drop_down_string_entry_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaViewsAdminPageAccountsDropDownStringEntryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_views_admin_page_accounts_drop_down_string_entry_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaViewsAdminPageAccountsDropDownStringEntry), 0, (GInstanceInitFunc) tuba_views_admin_page_accounts_drop_down_string_entry_instance_init, NULL };
	GType tuba_views_admin_page_accounts_drop_down_string_entry_type_id;
	tuba_views_admin_page_accounts_drop_down_string_entry_type_id = g_type_register_static (G_TYPE_OBJECT, "TubaViewsAdminPageAccountsDropDownStringEntry", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaViewsAdminPageAccountsDropDownStringEntry_private_offset = g_type_add_instance_private (tuba_views_admin_page_accounts_drop_down_string_entry_type_id, sizeof (TubaViewsAdminPageAccountsDropDownStringEntryPrivate));
	return tuba_views_admin_page_accounts_drop_down_string_entry_type_id;
}

static GType
tuba_views_admin_page_accounts_drop_down_string_entry_get_type (void)
{
	static GType tuba_views_admin_page_accounts_drop_down_string_entry_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_views_admin_page_accounts_drop_down_string_entry_type_id__once)) {
		GType tuba_views_admin_page_accounts_drop_down_string_entry_type_id;
		tuba_views_admin_page_accounts_drop_down_string_entry_type_id = tuba_views_admin_page_accounts_drop_down_string_entry_get_type_once ();
		g_once_init_leave_pointer (&tuba_views_admin_page_accounts_drop_down_string_entry_type_id__once, tuba_views_admin_page_accounts_drop_down_string_entry_type_id);
	}
	return tuba_views_admin_page_accounts_drop_down_string_entry_type_id__once;
}

static void
_vala_tuba_views_admin_page_accounts_drop_down_string_entry_get_property (GObject * object,
                                                                          guint property_id,
                                                                          GValue * value,
                                                                          GParamSpec * pspec)
{
	TubaViewsAdminPageAccountsDropDownStringEntry * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_TYPE_DROP_DOWN_STRING_ENTRY, TubaViewsAdminPageAccountsDropDownStringEntry);
	switch (property_id) {
		case TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_DROP_DOWN_STRING_ENTRY_API_PROPERTY:
		g_value_set_string (value, tuba_views_admin_page_accounts_drop_down_string_entry_get_api (self));
		break;
		case TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_DROP_DOWN_STRING_ENTRY_TITLE_PROPERTY:
		g_value_set_string (value, tuba_views_admin_page_accounts_drop_down_string_entry_get_title (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_views_admin_page_accounts_drop_down_string_entry_set_property (GObject * object,
                                                                          guint property_id,
                                                                          const GValue * value,
                                                                          GParamSpec * pspec)
{
	TubaViewsAdminPageAccountsDropDownStringEntry * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_TYPE_DROP_DOWN_STRING_ENTRY, TubaViewsAdminPageAccountsDropDownStringEntry);
	switch (property_id) {
		case TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_DROP_DOWN_STRING_ENTRY_API_PROPERTY:
		tuba_views_admin_page_accounts_drop_down_string_entry_set_api (self, g_value_get_string (value));
		break;
		case TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_DROP_DOWN_STRING_ENTRY_TITLE_PROPERTY:
		tuba_views_admin_page_accounts_drop_down_string_entry_set_title (self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static inline gpointer
tuba_views_admin_page_accounts_account_dialog_get_instance_private (TubaViewsAdminPageAccountsAccountDialog* self)
{
	return G_STRUCT_MEMBER_P (self, TubaViewsAdminPageAccountsAccountDialog_private_offset);
}

static gchar*
string_replace (const gchar* self,
                const gchar* old,
                const gchar* replacement)
{
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	GError* _inner_error0_ = NULL;
	gchar* result;
	g_return_val_if_fail (self != NULL, NULL);
	g_return_val_if_fail (old != NULL, NULL);
	g_return_val_if_fail (replacement != NULL, NULL);
	if ((*((gchar*) self)) == '\0') {
		_tmp1_ = TRUE;
	} else {
		_tmp1_ = (*((gchar*) old)) == '\0';
	}
	if (_tmp1_) {
		_tmp0_ = TRUE;
	} else {
		_tmp0_ = g_strcmp0 (old, replacement) == 0;
	}
	if (_tmp0_) {
		gchar* _tmp2_;
		_tmp2_ = g_strdup (self);
		result = _tmp2_;
		return result;
	}
	{
		GRegex* regex = NULL;
		gchar* _tmp3_;
		gchar* _tmp4_;
		GRegex* _tmp5_;
		GRegex* _tmp6_;
		gchar* _tmp7_ = NULL;
		GRegex* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		_tmp3_ = g_regex_escape_string (old, -1);
		_tmp4_ = _tmp3_;
		_tmp5_ = g_regex_new (_tmp4_, 0, 0, &_inner_error0_);
		_tmp6_ = _tmp5_;
		_g_free0 (_tmp4_);
		regex = _tmp6_;
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			if (_inner_error0_->domain == G_REGEX_ERROR) {
				goto __catch0_g_regex_error;
			}
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
			g_clear_error (&_inner_error0_);
			return NULL;
		}
		_tmp8_ = regex;
		_tmp9_ = g_regex_replace_literal (_tmp8_, self, (gssize) -1, 0, replacement, 0, &_inner_error0_);
		_tmp7_ = _tmp9_;
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			_g_regex_unref0 (regex);
			if (_inner_error0_->domain == G_REGEX_ERROR) {
				goto __catch0_g_regex_error;
			}
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
			g_clear_error (&_inner_error0_);
			return NULL;
		}
		_tmp10_ = _tmp7_;
		_tmp7_ = NULL;
		result = _tmp10_;
		_g_free0 (_tmp7_);
		_g_regex_unref0 (regex);
		return result;
	}
	goto __finally0;
	__catch0_g_regex_error:
	{
		g_clear_error (&_inner_error0_);
		g_assert_not_reached ();
	}
	__finally0:
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
	g_clear_error (&_inner_error0_);
	return NULL;
}

static void
_vala_array_add128 (gchar** * array,
                    gint* length,
                    gint* size,
                    gchar* value)
{
	if ((*length) == (*size)) {
		*size = (*size) ? (2 * (*size)) : 4;
		*array = g_renew (gchar*, *array, (*size) + 1);
	}
	(*array)[(*length)++] = value;
	(*array)[*length] = NULL;
}

static void
_tuba_views_admin_page_accounts_account_dialog_on_approve_gtk_button_clicked (GtkButton* _sender,
                                                                              gpointer self)
{
	tuba_views_admin_page_accounts_account_dialog_on_approve ((TubaViewsAdminPageAccountsAccountDialog*) self);
}

static void
_tuba_views_admin_page_accounts_account_dialog_on_reject_gtk_button_clicked (GtkButton* _sender,
                                                                             gpointer self)
{
	tuba_views_admin_page_accounts_account_dialog_on_reject ((TubaViewsAdminPageAccountsAccountDialog*) self);
}

static void
_tuba_views_admin_page_accounts_account_dialog_add_toast_tuba_views_admin_page_accounts_account_dialog_undo_row_on_error (TubaViewsAdminPageAccountsAccountDialogUndoRow* _sender,
                                                                                                                          const gchar* message,
                                                                                                                          guint timeout,
                                                                                                                          gpointer self)
{
	tuba_views_admin_page_accounts_account_dialog_add_toast ((TubaViewsAdminPageAccountsAccountDialog*) self, message, timeout);
}

static void
_tuba_views_admin_page_accounts_account_dialog_mark_for_refresh_tuba_views_admin_page_accounts_account_dialog_undo_row_undone (TubaViewsAdminPageAccountsAccountDialogUndoRow* _sender,
                                                                                                                               gpointer self)
{
	tuba_views_admin_page_accounts_account_dialog_mark_for_refresh ((TubaViewsAdminPageAccountsAccountDialog*) self);
}

static TubaViewsAdminPageAccountsAccountDialog*
tuba_views_admin_page_accounts_account_dialog_construct (GType object_type,
                                                         TubaAPIAdminAccount* account)
{
	TubaViewsAdminPageAccountsAccountDialog * self = NULL;
	TubaAPIAccount* _tmp0_;
	TubaAPIAccount* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	TubaAPIAccount* _tmp5_;
	TubaAPIAccount* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	TubaAPIAccount* _tmp9_;
	TubaAPIAccount* _tmp10_;
	gchar* _tmp11_;
	gchar* _tmp12_;
	gchar* _tmp13_;
	AdwPreferencesGroup* profile_group = NULL;
	AdwPreferencesGroup* _tmp14_;
	AdwPreferencesPage* _tmp15_;
	AdwPreferencesGroup* _tmp16_;
	TubaWidgetsAccount* profile = NULL;
	TubaAPIAccount* _tmp17_;
	TubaAPIAccount* _tmp18_;
	GtkWidget* _tmp19_;
	TubaWidgetsAccount* _tmp20_;
	TubaWidgetsAccount* _tmp21_;
	TubaWidgetsAccount* _tmp22_;
	AdwPreferencesGroup* _tmp23_;
	TubaWidgetsAccount* _tmp24_;
	AdwPreferencesGroup* info_group = NULL;
	AdwPreferencesGroup* _tmp25_;
	AdwPreferencesPage* _tmp26_;
	AdwPreferencesGroup* _tmp27_;
	TubaAPIAccount* _tmp28_;
	TubaAPIAccount* _tmp29_;
	const gchar* _tmp30_;
	const gchar* _tmp31_;
	const gchar* _tmp49_ = NULL;
	TubaAPIAccountRole* _tmp50_;
	TubaAPIAccountRole* _tmp51_;
	AdwPreferencesGroup* _tmp56_;
	gchar* _tmp57_;
	gchar* _tmp58_;
	AdwActionRow* _tmp59_ = NULL;
	AdwActionRow* _tmp60_;
	const gchar* _tmp61_ = NULL;
	const gchar* _tmp62_;
	const gchar* _tmp63_;
	AdwActionRow* e_mail_row = NULL;
	gchar* _tmp66_;
	gchar* _tmp67_;
	AdwActionRow* _tmp68_ = NULL;
	gboolean _tmp69_;
	gboolean _tmp70_;
	AdwPreferencesGroup* _tmp83_;
	AdwActionRow* _tmp84_;
	gchar** ips = NULL;
	gchar** _tmp85_;
	gint ips_length1;
	gint _ips_size_;
	GeeArrayList* _tmp86_;
	GeeArrayList* _tmp87_;
	gchar* _tmp101_ = NULL;
	gchar** _tmp102_;
	gint _tmp102__length1;
	AdwPreferencesGroup* _tmp106_;
	gchar* _tmp107_;
	gchar* _tmp108_;
	AdwActionRow* _tmp109_ = NULL;
	AdwActionRow* _tmp110_;
	AdwPreferencesGroup* actions_row = NULL;
	AdwPreferencesGroup* _tmp111_;
	AdwPreferencesPage* _tmp112_;
	AdwPreferencesGroup* _tmp113_;
	gboolean _tmp114_;
	gboolean _tmp115_;
	gboolean _tmp152_;
	gboolean _tmp153_;
	gboolean _tmp160_;
	gboolean _tmp161_;
	gboolean _tmp168_;
	gboolean _tmp169_;
	g_return_val_if_fail (account != NULL, NULL);
	self = (TubaViewsAdminPageAccountsAccountDialog*) g_object_new (object_type, NULL);
	_tmp0_ = tuba_api_admin_account_get_account (account);
	_tmp1_ = _tmp0_;
	_tmp2_ = tuba_api_account_get_id (_tmp1_);
	_tmp3_ = _tmp2_;
	_tmp4_ = g_strdup (_tmp3_);
	_g_free0 (self->priv->account_id);
	self->priv->account_id = _tmp4_;
	_tmp5_ = tuba_api_admin_account_get_account (account);
	_tmp6_ = _tmp5_;
	_tmp7_ = tuba_api_account_get_full_handle (_tmp6_);
	_tmp8_ = _tmp7_;
	_g_free0 (self->priv->account_handle);
	self->priv->account_handle = _tmp8_;
	_tmp9_ = tuba_api_admin_account_get_account (account);
	_tmp10_ = _tmp9_;
	_tmp11_ = tuba_api_account_get_full_handle (_tmp10_);
	_tmp12_ = _tmp11_;
	_tmp13_ = _tmp12_;
	adw_dialog_set_title ((AdwDialog*) self, _tmp13_);
	_g_free0 (_tmp13_);
	_tmp14_ = (AdwPreferencesGroup*) adw_preferences_group_new ();
	g_object_ref_sink (_tmp14_);
	profile_group = _tmp14_;
	_tmp15_ = self->priv->page;
	_tmp16_ = profile_group;
	adw_preferences_page_add (_tmp15_, _tmp16_);
	_tmp17_ = tuba_api_admin_account_get_account (account);
	_tmp18_ = _tmp17_;
	_tmp19_ = tuba_widgetizable_to_widget ((TubaWidgetizable*) _tmp18_);
	profile = G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, TUBA_WIDGETS_TYPE_ACCOUNT, TubaWidgetsAccount);
	_tmp20_ = profile;
	gtk_widget_set_overflow ((GtkWidget*) _tmp20_, GTK_OVERFLOW_HIDDEN);
	_tmp21_ = profile;
	tuba_widgets_account_set_disable_profile_open (_tmp21_, TRUE);
	_tmp22_ = profile;
	gtk_widget_add_css_class ((GtkWidget*) _tmp22_, "card");
	_tmp23_ = profile_group;
	_tmp24_ = profile;
	adw_preferences_group_add (_tmp23_, (GtkWidget*) _tmp24_);
	_tmp25_ = (AdwPreferencesGroup*) adw_preferences_group_new ();
	g_object_ref_sink (_tmp25_);
	info_group = _tmp25_;
	_tmp26_ = self->priv->page;
	_tmp27_ = info_group;
	adw_preferences_page_add (_tmp26_, _tmp27_);
	_tmp28_ = tuba_api_admin_account_get_account (account);
	_tmp29_ = _tmp28_;
	_tmp30_ = tuba_api_account_get_created_at (_tmp29_);
	_tmp31_ = _tmp30_;
	if (_tmp31_ != NULL) {
		GDateTime* join_date = NULL;
		TubaAPIAccount* _tmp32_;
		TubaAPIAccount* _tmp33_;
		const gchar* _tmp34_;
		const gchar* _tmp35_;
		GDateTime* _tmp36_;
		GDateTime* _tmp37_;
		GTimeZone* _tmp38_;
		GTimeZone* _tmp39_;
		GDateTime* _tmp40_;
		AdwPreferencesGroup* _tmp41_;
		gchar* _tmp42_;
		GDateTime* _tmp43_;
		gchar* _tmp44_;
		gchar* _tmp45_;
		gchar* _tmp46_;
		AdwActionRow* _tmp47_ = NULL;
		AdwActionRow* _tmp48_;
		_tmp32_ = tuba_api_admin_account_get_account (account);
		_tmp33_ = _tmp32_;
		_tmp34_ = tuba_api_account_get_created_at (_tmp33_);
		_tmp35_ = _tmp34_;
		_tmp36_ = g_date_time_new_from_iso8601 (_tmp35_, NULL);
		join_date = _tmp36_;
		_tmp37_ = join_date;
		_tmp38_ = g_time_zone_new_local ();
		_tmp39_ = _tmp38_;
		_tmp40_ = g_date_time_to_timezone (_tmp37_, _tmp39_);
		_g_date_time_unref0 (join_date);
		join_date = _tmp40_;
		_g_time_zone_unref0 (_tmp39_);
		_tmp41_ = info_group;
		_tmp42_ = g_strdup (_ ("Joined"));
		_tmp43_ = join_date;
		_tmp44_ = g_date_time_format (_tmp43_, _ ("%B %e, %Y"));
		_tmp45_ = _tmp44_;
		_tmp46_ = string_replace (_tmp45_, " ", "");
		_tmp47_ = (AdwActionRow*) adw_action_row_new ();
		adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp47_, _tmp42_);
		_g_free0 (_tmp42_);
		adw_action_row_set_subtitle (_tmp47_, _tmp46_);
		_g_free0 (_tmp46_);
		adw_action_row_set_subtitle_selectable (_tmp47_, TRUE);
		g_object_ref_sink (_tmp47_);
		_tmp48_ = _tmp47_;
		adw_preferences_group_add (_tmp41_, (GtkWidget*) _tmp48_);
		_g_object_unref0 (_tmp48_);
		_g_free0 (_tmp45_);
		_g_date_time_unref0 (join_date);
	}
	_tmp50_ = tuba_api_admin_account_get_role (account);
	_tmp51_ = _tmp50_;
	if (_tmp51_ == NULL) {
		_tmp49_ = _ ("None");
	} else {
		TubaAPIAccountRole* _tmp52_;
		TubaAPIAccountRole* _tmp53_;
		const gchar* _tmp54_;
		const gchar* _tmp55_;
		_tmp52_ = tuba_api_admin_account_get_role (account);
		_tmp53_ = _tmp52_;
		_tmp54_ = tuba_api_account_role_get_name (_tmp53_);
		_tmp55_ = _tmp54_;
		_tmp49_ = _tmp55_;
	}
	_tmp56_ = info_group;
	_tmp57_ = g_strdup (_ ("Role"));
	_tmp58_ = g_strdup (_tmp49_);
	_tmp59_ = (AdwActionRow*) adw_action_row_new ();
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp59_, _tmp57_);
	_g_free0 (_tmp57_);
	adw_action_row_set_subtitle (_tmp59_, _tmp58_);
	_g_free0 (_tmp58_);
	adw_action_row_set_subtitle_selectable (_tmp59_, TRUE);
	g_object_ref_sink (_tmp59_);
	_tmp60_ = _tmp59_;
	adw_preferences_group_add (_tmp56_, (GtkWidget*) _tmp60_);
	_g_object_unref0 (_tmp60_);
	_tmp62_ = tuba_api_admin_account_get_email (account);
	_tmp63_ = _tmp62_;
	if (_tmp63_ == NULL) {
		_tmp61_ = _ ("None");
	} else {
		const gchar* _tmp64_;
		const gchar* _tmp65_;
		_tmp64_ = tuba_api_admin_account_get_email (account);
		_tmp65_ = _tmp64_;
		_tmp61_ = _tmp65_;
	}
	_tmp66_ = g_strdup (_ ("E-mail"));
	_tmp67_ = g_strdup (_tmp61_);
	_tmp68_ = (AdwActionRow*) adw_action_row_new ();
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp68_, _tmp66_);
	_g_free0 (_tmp66_);
	adw_action_row_set_subtitle (_tmp68_, _tmp67_);
	_g_free0 (_tmp67_);
	adw_action_row_set_subtitle_selectable (_tmp68_, TRUE);
	g_object_ref_sink (_tmp68_);
	e_mail_row = _tmp68_;
	_tmp69_ = tuba_api_admin_account_get_confirmed (account);
	_tmp70_ = _tmp69_;
	if (_tmp70_ == TRUE) {
		AdwActionRow* _tmp71_;
		gchar* _tmp72_;
		gchar** _tmp73_;
		gchar* _tmp74_;
		GtkImage* _tmp75_ = NULL;
		GtkImage* _tmp76_;
		_tmp71_ = e_mail_row;
		_tmp72_ = g_strdup ("success");
		_tmp73_ = g_new0 (gchar*, 1 + 1);
		_tmp73_[0] = _tmp72_;
		_tmp74_ = g_strdup (_ ("Confirmed"));
		_tmp75_ = (GtkImage*) gtk_image_new_from_icon_name ("tuba-check-round-outline-symbolic");
		gtk_widget_set_css_classes ((GtkWidget*) _tmp75_, _tmp73_);
		_tmp73_ = (_vala_array_free (_tmp73_, 1, (GDestroyNotify) g_free), NULL);
		gtk_widget_set_valign ((GtkWidget*) _tmp75_, GTK_ALIGN_CENTER);
		gtk_widget_set_tooltip_text ((GtkWidget*) _tmp75_, _tmp74_);
		_g_free0 (_tmp74_);
		g_object_ref_sink (_tmp75_);
		_tmp76_ = _tmp75_;
		adw_action_row_add_suffix (_tmp71_, (GtkWidget*) _tmp76_);
		_g_object_unref0 (_tmp76_);
	} else {
		AdwActionRow* _tmp77_;
		gchar* _tmp78_;
		gchar** _tmp79_;
		gchar* _tmp80_;
		GtkImage* _tmp81_ = NULL;
		GtkImage* _tmp82_;
		_tmp77_ = e_mail_row;
		_tmp78_ = g_strdup ("error");
		_tmp79_ = g_new0 (gchar*, 1 + 1);
		_tmp79_[0] = _tmp78_;
		_tmp80_ = g_strdup (_ ("Not Confirmed"));
		_tmp81_ = (GtkImage*) gtk_image_new_from_icon_name ("tuba-cross-large-symbolic");
		gtk_widget_set_css_classes ((GtkWidget*) _tmp81_, _tmp79_);
		_tmp79_ = (_vala_array_free (_tmp79_, 1, (GDestroyNotify) g_free), NULL);
		gtk_widget_set_valign ((GtkWidget*) _tmp81_, GTK_ALIGN_CENTER);
		gtk_widget_set_tooltip_text ((GtkWidget*) _tmp81_, _tmp80_);
		_g_free0 (_tmp80_);
		g_object_ref_sink (_tmp81_);
		_tmp82_ = _tmp81_;
		adw_action_row_add_suffix (_tmp77_, (GtkWidget*) _tmp82_);
		_g_object_unref0 (_tmp82_);
	}
	_tmp83_ = info_group;
	_tmp84_ = e_mail_row;
	adw_preferences_group_add (_tmp83_, (GtkWidget*) _tmp84_);
	_tmp85_ = g_new0 (gchar*, 0 + 1);
	ips = _tmp85_;
	ips_length1 = 0;
	_ips_size_ = ips_length1;
	_tmp86_ = tuba_api_admin_account_get_ips (account);
	_tmp87_ = _tmp86_;
	if (_tmp87_ != NULL) {
		{
			GeeArrayList* _account_ip_list = NULL;
			GeeArrayList* _tmp88_;
			GeeArrayList* _tmp89_;
			gint _account_ip_size = 0;
			GeeArrayList* _tmp90_;
			gint _tmp91_;
			gint _tmp92_;
			gint _account_ip_index = 0;
			_tmp88_ = tuba_api_admin_account_get_ips (account);
			_tmp89_ = _tmp88_;
			_account_ip_list = _tmp89_;
			_tmp90_ = _account_ip_list;
			_tmp91_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp90_);
			_tmp92_ = _tmp91_;
			_account_ip_size = _tmp92_;
			_account_ip_index = -1;
			while (TRUE) {
				gint _tmp93_;
				gint _tmp94_;
				TubaAPIAdminAccountIPAddress* account_ip = NULL;
				GeeArrayList* _tmp95_;
				gpointer _tmp96_;
				TubaAPIAdminAccountIPAddress* _tmp97_;
				const gchar* _tmp98_;
				const gchar* _tmp99_;
				gchar* _tmp100_;
				_account_ip_index = _account_ip_index + 1;
				_tmp93_ = _account_ip_index;
				_tmp94_ = _account_ip_size;
				if (!(_tmp93_ < _tmp94_)) {
					break;
				}
				_tmp95_ = _account_ip_list;
				_tmp96_ = gee_abstract_list_get ((GeeAbstractList*) _tmp95_, _account_ip_index);
				account_ip = (TubaAPIAdminAccountIPAddress*) _tmp96_;
				_tmp97_ = account_ip;
				_tmp98_ = tuba_api_admin_account_ip_address_get_ip (_tmp97_);
				_tmp99_ = _tmp98_;
				_tmp100_ = g_strdup (_tmp99_);
				_vala_array_add128 (&ips, &ips_length1, &_ips_size_, _tmp100_);
				_g_object_unref0 (account_ip);
			}
		}
	}
	_tmp102_ = ips;
	_tmp102__length1 = ips_length1;
	if (_tmp102__length1 > 0) {
		gchar** _tmp103_;
		gint _tmp103__length1;
		gchar* _tmp104_;
		_tmp103_ = ips;
		_tmp103__length1 = ips_length1;
		_tmp104_ = _vala_g_strjoinv ("\n", _tmp103_, (gint) _tmp103__length1);
		_g_free0 (_tmp101_);
		_tmp101_ = _tmp104_;
	} else {
		gchar* _tmp105_;
		_tmp105_ = g_strdup (_ ("None"));
		_g_free0 (_tmp101_);
		_tmp101_ = _tmp105_;
	}
	_tmp106_ = info_group;
	_tmp107_ = g_strdup ("IPs");
	_tmp108_ = _tmp101_;
	_tmp101_ = NULL;
	_tmp109_ = (AdwActionRow*) adw_action_row_new ();
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp109_, _tmp107_);
	_g_free0 (_tmp107_);
	adw_action_row_set_subtitle (_tmp109_, _tmp108_);
	_g_free0 (_tmp108_);
	adw_action_row_set_subtitle_selectable (_tmp109_, TRUE);
	g_object_ref_sink (_tmp109_);
	_tmp110_ = _tmp109_;
	adw_preferences_group_add (_tmp106_, (GtkWidget*) _tmp110_);
	_g_object_unref0 (_tmp110_);
	_tmp111_ = (AdwPreferencesGroup*) adw_preferences_group_new ();
	g_object_ref_sink (_tmp111_);
	actions_row = _tmp111_;
	_tmp112_ = self->priv->page;
	_tmp113_ = actions_row;
	adw_preferences_page_add (_tmp112_, _tmp113_);
	_tmp114_ = tuba_api_admin_account_get_approved (account);
	_tmp115_ = _tmp114_;
	if (!_tmp115_) {
		gchar* _tmp116_ = NULL;
		gboolean _tmp117_ = FALSE;
		const gchar* _tmp118_;
		const gchar* _tmp119_;
		gchar* note = NULL;
		gchar* _tmp127_;
		gchar* _tmp128_;
		const gchar* _tmp129_;
		gchar* _tmp130_;
		AdwActionRow* _tmp131_ = NULL;
		GtkButton* approve_btn = NULL;
		gchar* _tmp132_;
		gchar* _tmp133_;
		gchar* _tmp134_;
		gchar** _tmp135_;
		gchar* _tmp136_;
		GtkButton* _tmp137_ = NULL;
		GtkButton* _tmp138_;
		GtkButton* reject_button = NULL;
		gchar* _tmp139_;
		gchar* _tmp140_;
		gchar* _tmp141_;
		gchar** _tmp142_;
		gchar* _tmp143_;
		GtkButton* _tmp144_ = NULL;
		GtkButton* _tmp145_;
		AdwActionRow* _tmp146_;
		GtkButton* _tmp147_;
		AdwActionRow* _tmp148_;
		GtkButton* _tmp149_;
		AdwPreferencesGroup* _tmp150_;
		AdwActionRow* _tmp151_;
		_tmp118_ = tuba_api_admin_account_get_invite_request (account);
		_tmp119_ = _tmp118_;
		if (_tmp119_ == NULL) {
			_tmp117_ = TRUE;
		} else {
			const gchar* _tmp120_;
			const gchar* _tmp121_;
			_tmp120_ = tuba_api_admin_account_get_invite_request (account);
			_tmp121_ = _tmp120_;
			_tmp117_ = g_strcmp0 (_tmp121_, "") == 0;
		}
		if (_tmp117_) {
			gchar* _tmp122_;
			_tmp122_ = g_strdup (_ ("No Reason Given"));
			_g_free0 (_tmp116_);
			_tmp116_ = _tmp122_;
		} else {
			const gchar* _tmp123_;
			const gchar* _tmp124_;
			const gchar* _tmp125_;
			gchar* _tmp126_;
			_tmp123_ = tuba_api_admin_account_get_invite_request (account);
			_tmp124_ = _tmp123_;
			_tmp125_ = string_to_string (_tmp124_);
			_tmp126_ = g_strconcat ("\"", _tmp125_, "\"", NULL);
			_g_free0 (_tmp116_);
			_tmp116_ = _tmp126_;
		}
		_tmp127_ = _tmp116_;
		_tmp116_ = NULL;
		note = _tmp127_;
		_tmp128_ = g_strdup (_ ("Awaiting Approval"));
		_tmp129_ = note;
		_tmp130_ = g_strdup (_tmp129_);
		_tmp131_ = (AdwActionRow*) adw_action_row_new ();
		gtk_list_box_row_set_activatable ((GtkListBoxRow*) _tmp131_, FALSE);
		adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp131_, _tmp128_);
		_g_free0 (_tmp128_);
		adw_action_row_set_subtitle (_tmp131_, _tmp130_);
		_g_free0 (_tmp130_);
		g_object_ref_sink (_tmp131_);
		_g_object_unref0 (self->priv->approval_row);
		self->priv->approval_row = _tmp131_;
		_tmp132_ = g_strdup ("flat");
		_tmp133_ = g_strdup ("circular");
		_tmp134_ = g_strdup ("success");
		_tmp135_ = g_new0 (gchar*, 3 + 1);
		_tmp135_[0] = _tmp132_;
		_tmp135_[1] = _tmp133_;
		_tmp135_[2] = _tmp134_;
		_tmp136_ = g_strdup (_ ("Approve"));
		_tmp137_ = (GtkButton*) gtk_button_new_from_icon_name ("tuba-check-round-outline-symbolic");
		gtk_widget_set_valign ((GtkWidget*) _tmp137_, GTK_ALIGN_CENTER);
		gtk_widget_set_css_classes ((GtkWidget*) _tmp137_, _tmp135_);
		_tmp135_ = (_vala_array_free (_tmp135_, 3, (GDestroyNotify) g_free), NULL);
		gtk_widget_set_tooltip_text ((GtkWidget*) _tmp137_, _tmp136_);
		_g_free0 (_tmp136_);
		g_object_ref_sink (_tmp137_);
		approve_btn = _tmp137_;
		_tmp138_ = approve_btn;
		g_signal_connect_object (_tmp138_, "clicked", (GCallback) _tuba_views_admin_page_accounts_account_dialog_on_approve_gtk_button_clicked, self, 0);
		_tmp139_ = g_strdup ("flat");
		_tmp140_ = g_strdup ("circular");
		_tmp141_ = g_strdup ("error");
		_tmp142_ = g_new0 (gchar*, 3 + 1);
		_tmp142_[0] = _tmp139_;
		_tmp142_[1] = _tmp140_;
		_tmp142_[2] = _tmp141_;
		_tmp143_ = g_strdup (_ ("Reject"));
		_tmp144_ = (GtkButton*) gtk_button_new_from_icon_name ("tuba-cross-large-symbolic");
		gtk_widget_set_valign ((GtkWidget*) _tmp144_, GTK_ALIGN_CENTER);
		gtk_widget_set_css_classes ((GtkWidget*) _tmp144_, _tmp142_);
		_tmp142_ = (_vala_array_free (_tmp142_, 3, (GDestroyNotify) g_free), NULL);
		gtk_widget_set_tooltip_text ((GtkWidget*) _tmp144_, _tmp143_);
		_g_free0 (_tmp143_);
		g_object_ref_sink (_tmp144_);
		reject_button = _tmp144_;
		_tmp145_ = reject_button;
		g_signal_connect_object (_tmp145_, "clicked", (GCallback) _tuba_views_admin_page_accounts_account_dialog_on_reject_gtk_button_clicked, self, 0);
		_tmp146_ = self->priv->approval_row;
		_tmp147_ = reject_button;
		adw_action_row_add_suffix (_tmp146_, (GtkWidget*) _tmp147_);
		_tmp148_ = self->priv->approval_row;
		_tmp149_ = approve_btn;
		adw_action_row_add_suffix (_tmp148_, (GtkWidget*) _tmp149_);
		_tmp150_ = actions_row;
		_tmp151_ = self->priv->approval_row;
		adw_preferences_group_add (_tmp150_, (GtkWidget*) _tmp151_);
		_g_object_unref0 (reject_button);
		_g_object_unref0 (approve_btn);
		_g_free0 (note);
		_g_free0 (_tmp116_);
	}
	_tmp152_ = tuba_api_admin_account_get_suspended (account);
	_tmp153_ = _tmp152_;
	if (_tmp153_) {
		TubaViewsAdminPageAccountsAccountDialogUndoRow* suspended_row = NULL;
		const gchar* _tmp154_;
		TubaViewsAdminPageAccountsAccountDialogUndoRow* _tmp155_;
		TubaViewsAdminPageAccountsAccountDialogUndoRow* _tmp156_;
		TubaViewsAdminPageAccountsAccountDialogUndoRow* _tmp157_;
		AdwPreferencesGroup* _tmp158_;
		TubaViewsAdminPageAccountsAccountDialogUndoRow* _tmp159_;
		_tmp154_ = self->priv->account_id;
		_tmp155_ = tuba_views_admin_page_accounts_account_dialog_undo_row_new (_ ("Suspended"), _tmp154_, "unsuspend");
		g_object_ref_sink (_tmp155_);
		suspended_row = _tmp155_;
		_tmp156_ = suspended_row;
		g_signal_connect_object (_tmp156_, "on-error", (GCallback) _tuba_views_admin_page_accounts_account_dialog_add_toast_tuba_views_admin_page_accounts_account_dialog_undo_row_on_error, self, 0);
		_tmp157_ = suspended_row;
		g_signal_connect_object (_tmp157_, "undone", (GCallback) _tuba_views_admin_page_accounts_account_dialog_mark_for_refresh_tuba_views_admin_page_accounts_account_dialog_undo_row_undone, self, 0);
		_tmp158_ = actions_row;
		_tmp159_ = suspended_row;
		adw_preferences_group_add (_tmp158_, (GtkWidget*) _tmp159_);
		_g_object_unref0 (suspended_row);
	}
	_tmp160_ = tuba_api_admin_account_get_silenced (account);
	_tmp161_ = _tmp160_;
	if (_tmp161_) {
		TubaViewsAdminPageAccountsAccountDialogUndoRow* silenced_row = NULL;
		const gchar* _tmp162_;
		TubaViewsAdminPageAccountsAccountDialogUndoRow* _tmp163_;
		TubaViewsAdminPageAccountsAccountDialogUndoRow* _tmp164_;
		TubaViewsAdminPageAccountsAccountDialogUndoRow* _tmp165_;
		AdwPreferencesGroup* _tmp166_;
		TubaViewsAdminPageAccountsAccountDialogUndoRow* _tmp167_;
		_tmp162_ = self->priv->account_id;
		_tmp163_ = tuba_views_admin_page_accounts_account_dialog_undo_row_new (_ ("Limited"), _tmp162_, "unsilence");
		g_object_ref_sink (_tmp163_);
		silenced_row = _tmp163_;
		_tmp164_ = silenced_row;
		g_signal_connect_object (_tmp164_, "on-error", (GCallback) _tuba_views_admin_page_accounts_account_dialog_add_toast_tuba_views_admin_page_accounts_account_dialog_undo_row_on_error, self, 0);
		_tmp165_ = silenced_row;
		g_signal_connect_object (_tmp165_, "undone", (GCallback) _tuba_views_admin_page_accounts_account_dialog_mark_for_refresh_tuba_views_admin_page_accounts_account_dialog_undo_row_undone, self, 0);
		_tmp166_ = actions_row;
		_tmp167_ = silenced_row;
		adw_preferences_group_add (_tmp166_, (GtkWidget*) _tmp167_);
		_g_object_unref0 (silenced_row);
	}
	_tmp168_ = tuba_api_admin_account_get_disabled (account);
	_tmp169_ = _tmp168_;
	if (_tmp169_) {
		TubaViewsAdminPageAccountsAccountDialogUndoRow* disabled_row = NULL;
		const gchar* _tmp170_;
		TubaViewsAdminPageAccountsAccountDialogUndoRow* _tmp171_;
		TubaViewsAdminPageAccountsAccountDialogUndoRow* _tmp172_;
		TubaViewsAdminPageAccountsAccountDialogUndoRow* _tmp173_;
		AdwPreferencesGroup* _tmp174_;
		TubaViewsAdminPageAccountsAccountDialogUndoRow* _tmp175_;
		_tmp170_ = self->priv->account_id;
		_tmp171_ = tuba_views_admin_page_accounts_account_dialog_undo_row_new (_ ("Disabled"), _tmp170_, "enable");
		g_object_ref_sink (_tmp171_);
		disabled_row = _tmp171_;
		_tmp172_ = disabled_row;
		g_signal_connect_object (_tmp172_, "on-error", (GCallback) _tuba_views_admin_page_accounts_account_dialog_add_toast_tuba_views_admin_page_accounts_account_dialog_undo_row_on_error, self, 0);
		_tmp173_ = disabled_row;
		g_signal_connect_object (_tmp173_, "undone", (GCallback) _tuba_views_admin_page_accounts_account_dialog_mark_for_refresh_tuba_views_admin_page_accounts_account_dialog_undo_row_undone, self, 0);
		_tmp174_ = actions_row;
		_tmp175_ = disabled_row;
		adw_preferences_group_add (_tmp174_, (GtkWidget*) _tmp175_);
		_g_object_unref0 (disabled_row);
	}
	_g_object_unref0 (actions_row);
	_g_free0 (_tmp101_);
	ips = (_vala_array_free (ips, ips_length1, (GDestroyNotify) g_free), NULL);
	_g_object_unref0 (e_mail_row);
	_g_object_unref0 (info_group);
	_g_object_unref0 (profile);
	_g_object_unref0 (profile_group);
	return self;
}

static TubaViewsAdminPageAccountsAccountDialog*
tuba_views_admin_page_accounts_account_dialog_new (TubaAPIAdminAccount* account)
{
	return tuba_views_admin_page_accounts_account_dialog_construct (TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_TYPE_ACCOUNT_DIALOG, account);
}

static void
tuba_views_admin_page_accounts_account_dialog_add_toast (TubaViewsAdminPageAccountsAccountDialog* self,
                                                         const gchar* content,
                                                         guint timeout)
{
	AdwToastOverlay* _tmp0_;
	AdwToast* _tmp1_ = NULL;
	g_return_if_fail (self != NULL);
	g_return_if_fail (content != NULL);
	_tmp0_ = self->priv->toast_overlay;
	_tmp1_ = adw_toast_new (content);
	adw_toast_set_timeout (_tmp1_, timeout);
	adw_toast_overlay_add_toast (_tmp0_, _tmp1_);
}

static void
_tuba_views_admin_page_accounts_account_dialog_on_took_action_tuba_dialogs_admin_take_action_took_action (TubaDialogsAdminTakeAction* _sender,
                                                                                                          gpointer self)
{
	tuba_views_admin_page_accounts_account_dialog_on_took_action ((TubaViewsAdminPageAccountsAccountDialog*) self);
}

static void
tuba_views_admin_page_accounts_account_dialog_show_take_action_dialog (TubaViewsAdminPageAccountsAccountDialog* self)
{
	TubaDialogsAdminTakeAction* dlg = NULL;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	TubaDialogsAdminTakeAction* _tmp2_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->account_id;
	_tmp1_ = self->priv->account_handle;
	_tmp2_ = tuba_dialogs_admin_take_action_new (_tmp0_, _tmp1_, NULL);
	g_object_ref_sink (_tmp2_);
	dlg = _tmp2_;
	g_signal_connect_object (dlg, "took-action", (GCallback) _tuba_views_admin_page_accounts_account_dialog_on_took_action_tuba_dialogs_admin_take_action_took_action, self, 0);
	adw_dialog_present ((AdwDialog*) dlg, (GtkWidget*) self);
	_g_object_unref0 (dlg);
}

static void
tuba_views_admin_page_accounts_account_dialog_on_took_action (TubaViewsAdminPageAccountsAccountDialog* self)
{
	g_return_if_fail (self != NULL);
	tuba_views_admin_page_accounts_account_dialog_mark_for_refresh (self);
	tuba_views_admin_page_accounts_account_dialog_on_close (self);
}

static void
tuba_views_admin_page_accounts_account_dialog_mark_for_refresh (TubaViewsAdminPageAccountsAccountDialog* self)
{
	g_return_if_fail (self != NULL);
	self->priv->should_refresh = TRUE;
}

static void
tuba_views_admin_page_accounts_account_dialog_on_close (TubaViewsAdminPageAccountsAccountDialog* self)
{
	g_return_if_fail (self != NULL);
	if (self->priv->should_refresh) {
		g_signal_emit (self, tuba_views_admin_page_accounts_account_dialog_signals[TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_ACCOUNT_DIALOG_REFRESH_SIGNAL], 0);
	}
	adw_dialog_force_close ((AdwDialog*) self);
}

static void
tuba_views_admin_page_accounts_account_dialog_on_approve (TubaViewsAdminPageAccountsAccountDialog* self)
{
	g_return_if_fail (self != NULL);
	tuba_views_admin_page_accounts_account_dialog_on_approve_real (self, NULL, NULL);
}

static void
tuba_views_admin_page_accounts_account_dialog_on_approve_real_data_free (gpointer _data)
{
	TubaViewsAdminPageAccountsAccountDialogOnApproveRealData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->self);
	g_slice_free (TubaViewsAdminPageAccountsAccountDialogOnApproveRealData, _data_);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
tuba_views_admin_page_accounts_account_dialog_on_approve_real (TubaViewsAdminPageAccountsAccountDialog* self,
                                                               GAsyncReadyCallback _callback_,
                                                               gpointer _user_data_)
{
	TubaViewsAdminPageAccountsAccountDialogOnApproveRealData* _data_;
	TubaViewsAdminPageAccountsAccountDialog* _tmp0_;
	g_return_if_fail (self != NULL);
	_data_ = g_slice_new0 (TubaViewsAdminPageAccountsAccountDialogOnApproveRealData);
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
	g_task_set_task_data (_data_->_async_result, _data_, tuba_views_admin_page_accounts_account_dialog_on_approve_real_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	tuba_views_admin_page_accounts_account_dialog_on_approve_real_co (_data_);
}

static void
tuba_views_admin_page_accounts_account_dialog_on_approve_real_finish (TubaViewsAdminPageAccountsAccountDialog* self,
                                                                      GAsyncResult* _res_)
{
	TubaViewsAdminPageAccountsAccountDialogOnApproveRealData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
}

static void
tuba_views_admin_page_accounts_account_dialog_on_approve_real_ready (GObject* source_object,
                                                                     GAsyncResult* _res_,
                                                                     gpointer _user_data_)
{
	TubaViewsAdminPageAccountsAccountDialogOnApproveRealData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	tuba_views_admin_page_accounts_account_dialog_on_approve_real_co (_data_);
}

static gboolean
tuba_views_admin_page_accounts_account_dialog_on_approve_real_co (TubaViewsAdminPageAccountsAccountDialogOnApproveRealData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		case 2:
		goto _state_2;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_tmp0_ = _data_->self->priv->account_handle;
	_data_->_tmp1_ = g_strdup_printf (_ ("Approve %s?"), _data_->_tmp0_);
	_data_->_tmp2_ = _data_->_tmp1_;
	_data_->_tmp3_ = (AdwAlertDialog*) adw_alert_dialog_new (_data_->_tmp2_, NULL);
	g_object_ref_sink (_data_->_tmp3_);
	_data_->_tmp4_ = _data_->_tmp3_;
	_g_free0 (_data_->_tmp2_);
	_data_->dlg = _data_->_tmp4_;
	_data_->_tmp5_ = _data_->dlg;
	adw_alert_dialog_add_response (_data_->_tmp5_, "no", _ ("Cancel"));
	_data_->_tmp6_ = _data_->dlg;
	adw_alert_dialog_set_response_appearance (_data_->_tmp6_, "no", ADW_RESPONSE_DEFAULT);
	_data_->_tmp7_ = _data_->dlg;
	adw_alert_dialog_add_response (_data_->_tmp7_, "yes", _ ("Approve"));
	_data_->_tmp8_ = _data_->dlg;
	adw_alert_dialog_set_response_appearance (_data_->_tmp8_, "yes", ADW_RESPONSE_DESTRUCTIVE);
	_data_->_tmp9_ = _data_->dlg;
	_data_->_state_ = 1;
	adw_alert_dialog_choose (_data_->_tmp9_, (GtkWidget*) _data_->self, NULL, tuba_views_admin_page_accounts_account_dialog_on_approve_real_ready, _data_);
	return FALSE;
	_state_1:
	_data_->_tmp10_ = adw_alert_dialog_choose_finish (_data_->_tmp9_, _data_->_res_);
	if (g_strcmp0 (_data_->_tmp10_, "yes") == 0) {
		_data_->_tmp11_ = _data_->self->priv->approval_row;
		gtk_widget_set_sensitive ((GtkWidget*) _data_->_tmp11_, FALSE);
		_data_->_tmp12_ = _data_->self->priv->account_id;
		_data_->_tmp13_ = string_to_string (_data_->_tmp12_);
		_data_->_tmp14_ = g_strconcat ("/api/v1/admin/accounts/", _data_->_tmp13_, "/approve", NULL);
		_data_->_tmp15_ = _data_->_tmp14_;
		_data_->_tmp16_ = tuba_accounts;
		_data_->_tmp17_ = tuba_account_store_get_active (_data_->_tmp16_);
		_data_->_tmp18_ = _data_->_tmp17_;
		_data_->_tmp19_ = _g_object_ref0 (_data_->_tmp18_);
		_data_->_tmp20_ = NULL;
		_data_->_tmp20_ = tuba_request_v2_new (_data_->_tmp15_, TUBA_REQUEST_V2_METHOD_POST);
		tuba_request_v2_set_account (_data_->_tmp20_, _data_->_tmp19_);
		_g_object_unref0 (_data_->_tmp19_);
		_data_->_tmp21_ = _data_->_tmp20_;
		_g_free0 (_data_->_tmp15_);
		_data_->req = _data_->_tmp21_;
		{
			_data_->_tmp22_ = _data_->req;
			_data_->_state_ = 2;
			tuba_request_v2_exec (_data_->_tmp22_, tuba_views_admin_page_accounts_account_dialog_on_approve_real_ready, _data_);
			return FALSE;
			_state_2:
			_data_->_tmp23_ = tuba_request_v2_exec_finish (_data_->_tmp22_, _data_->_res_, NULL, &_data_->_inner_error0_);
			_data_->_tmp24_ = _data_->_tmp23_;
			_g_object_unref0 (_data_->_tmp24_);
			if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
				goto __catch0_g_error;
			}
			_data_->_tmp25_ = _data_->self->priv->approval_row;
			gtk_widget_set_visible ((GtkWidget*) _data_->_tmp25_, FALSE);
			tuba_views_admin_page_accounts_account_dialog_mark_for_refresh (_data_->self);
		}
		goto __finally0;
		__catch0_g_error:
		{
			_data_->e = _data_->_inner_error0_;
			_data_->_inner_error0_ = NULL;
			_data_->_tmp26_ = _data_->self->priv->approval_row;
			gtk_widget_set_sensitive ((GtkWidget*) _data_->_tmp26_, TRUE);
			_data_->_tmp27_ = _data_->e;
			_data_->_tmp28_ = g_strdup_printf ("%i", _data_->_tmp27_->code);
			_data_->_tmp29_ = _data_->_tmp28_;
			_data_->_tmp30_ = _data_->e;
			_data_->_tmp31_ = _data_->_tmp30_->message;
			_data_->_tmp32_ = string_to_string (_data_->_tmp31_);
			_data_->_tmp33_ = g_strconcat ("Error while trying to approve account: ", _data_->_tmp29_, " ", _data_->_tmp32_, NULL);
			_data_->_tmp34_ = _data_->_tmp33_;
			g_warning ("Accounts.vala:507: %s", _data_->_tmp34_);
			_g_free0 (_data_->_tmp34_);
			_g_free0 (_data_->_tmp29_);
			_data_->_tmp35_ = _data_->e;
			_data_->_tmp36_ = _data_->_tmp35_->message;
			tuba_views_admin_page_accounts_account_dialog_add_toast (_data_->self, _data_->_tmp36_, (guint) 5);
			_g_error_free0 (_data_->e);
		}
		__finally0:
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
			_g_object_unref0 (_data_->req);
			_g_object_unref0 (_data_->dlg);
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error0_->message, g_quark_to_string (_data_->_inner_error0_->domain), _data_->_inner_error0_->code);
			g_clear_error (&_data_->_inner_error0_);
			g_object_unref (_data_->_async_result);
			return FALSE;
		}
		_g_object_unref0 (_data_->req);
	}
	_g_object_unref0 (_data_->dlg);
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!g_task_get_completed (_data_->_async_result)) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

static void
tuba_views_admin_page_accounts_account_dialog_on_reject (TubaViewsAdminPageAccountsAccountDialog* self)
{
	g_return_if_fail (self != NULL);
	tuba_views_admin_page_accounts_account_dialog_on_reject_real (self, NULL, NULL);
}

static void
tuba_views_admin_page_accounts_account_dialog_on_reject_real_data_free (gpointer _data)
{
	TubaViewsAdminPageAccountsAccountDialogOnRejectRealData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->self);
	g_slice_free (TubaViewsAdminPageAccountsAccountDialogOnRejectRealData, _data_);
}

static void
tuba_views_admin_page_accounts_account_dialog_on_reject_real (TubaViewsAdminPageAccountsAccountDialog* self,
                                                              GAsyncReadyCallback _callback_,
                                                              gpointer _user_data_)
{
	TubaViewsAdminPageAccountsAccountDialogOnRejectRealData* _data_;
	TubaViewsAdminPageAccountsAccountDialog* _tmp0_;
	g_return_if_fail (self != NULL);
	_data_ = g_slice_new0 (TubaViewsAdminPageAccountsAccountDialogOnRejectRealData);
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
	g_task_set_task_data (_data_->_async_result, _data_, tuba_views_admin_page_accounts_account_dialog_on_reject_real_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	tuba_views_admin_page_accounts_account_dialog_on_reject_real_co (_data_);
}

static void
tuba_views_admin_page_accounts_account_dialog_on_reject_real_finish (TubaViewsAdminPageAccountsAccountDialog* self,
                                                                     GAsyncResult* _res_)
{
	TubaViewsAdminPageAccountsAccountDialogOnRejectRealData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
}

static void
tuba_views_admin_page_accounts_account_dialog_on_reject_real_ready (GObject* source_object,
                                                                    GAsyncResult* _res_,
                                                                    gpointer _user_data_)
{
	TubaViewsAdminPageAccountsAccountDialogOnRejectRealData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	tuba_views_admin_page_accounts_account_dialog_on_reject_real_co (_data_);
}

static gboolean
tuba_views_admin_page_accounts_account_dialog_on_reject_real_co (TubaViewsAdminPageAccountsAccountDialogOnRejectRealData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		case 2:
		goto _state_2;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_tmp0_ = _data_->self->priv->account_handle;
	_data_->_tmp1_ = g_strdup_printf (_ ("Reject %s?"), _data_->_tmp0_);
	_data_->_tmp2_ = _data_->_tmp1_;
	_data_->_tmp3_ = (AdwAlertDialog*) adw_alert_dialog_new (_data_->_tmp2_, NULL);
	g_object_ref_sink (_data_->_tmp3_);
	_data_->_tmp4_ = _data_->_tmp3_;
	_g_free0 (_data_->_tmp2_);
	_data_->dlg = _data_->_tmp4_;
	_data_->_tmp5_ = _data_->dlg;
	adw_alert_dialog_add_response (_data_->_tmp5_, "no", _ ("Cancel"));
	_data_->_tmp6_ = _data_->dlg;
	adw_alert_dialog_set_response_appearance (_data_->_tmp6_, "no", ADW_RESPONSE_DEFAULT);
	_data_->_tmp7_ = _data_->dlg;
	adw_alert_dialog_add_response (_data_->_tmp7_, "yes", _ ("Reject"));
	_data_->_tmp8_ = _data_->dlg;
	adw_alert_dialog_set_response_appearance (_data_->_tmp8_, "yes", ADW_RESPONSE_DESTRUCTIVE);
	_data_->_tmp9_ = _data_->dlg;
	_data_->_state_ = 1;
	adw_alert_dialog_choose (_data_->_tmp9_, (GtkWidget*) _data_->self, NULL, tuba_views_admin_page_accounts_account_dialog_on_reject_real_ready, _data_);
	return FALSE;
	_state_1:
	_data_->_tmp10_ = adw_alert_dialog_choose_finish (_data_->_tmp9_, _data_->_res_);
	if (g_strcmp0 (_data_->_tmp10_, "yes") == 0) {
		_data_->_tmp11_ = _data_->self->priv->approval_row;
		gtk_widget_set_sensitive ((GtkWidget*) _data_->_tmp11_, FALSE);
		_data_->_tmp12_ = _data_->self->priv->account_id;
		_data_->_tmp13_ = string_to_string (_data_->_tmp12_);
		_data_->_tmp14_ = g_strconcat ("/api/v1/admin/accounts/", _data_->_tmp13_, "/reject", NULL);
		_data_->_tmp15_ = _data_->_tmp14_;
		_data_->_tmp16_ = tuba_accounts;
		_data_->_tmp17_ = tuba_account_store_get_active (_data_->_tmp16_);
		_data_->_tmp18_ = _data_->_tmp17_;
		_data_->_tmp19_ = _g_object_ref0 (_data_->_tmp18_);
		_data_->_tmp20_ = NULL;
		_data_->_tmp20_ = tuba_request_v2_new (_data_->_tmp15_, TUBA_REQUEST_V2_METHOD_POST);
		tuba_request_v2_set_account (_data_->_tmp20_, _data_->_tmp19_);
		_g_object_unref0 (_data_->_tmp19_);
		_data_->_tmp21_ = _data_->_tmp20_;
		_g_free0 (_data_->_tmp15_);
		_data_->req = _data_->_tmp21_;
		{
			_data_->_tmp22_ = _data_->req;
			_data_->_state_ = 2;
			tuba_request_v2_exec (_data_->_tmp22_, tuba_views_admin_page_accounts_account_dialog_on_reject_real_ready, _data_);
			return FALSE;
			_state_2:
			_data_->_tmp23_ = tuba_request_v2_exec_finish (_data_->_tmp22_, _data_->_res_, NULL, &_data_->_inner_error0_);
			_data_->_tmp24_ = _data_->_tmp23_;
			_g_object_unref0 (_data_->_tmp24_);
			if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
				goto __catch0_g_error;
			}
			_data_->_tmp25_ = _data_->self->priv->approval_row;
			gtk_widget_set_visible ((GtkWidget*) _data_->_tmp25_, FALSE);
			tuba_views_admin_page_accounts_account_dialog_mark_for_refresh (_data_->self);
		}
		goto __finally0;
		__catch0_g_error:
		{
			_data_->e = _data_->_inner_error0_;
			_data_->_inner_error0_ = NULL;
			_data_->_tmp26_ = _data_->self->priv->approval_row;
			gtk_widget_set_sensitive ((GtkWidget*) _data_->_tmp26_, TRUE);
			_data_->_tmp27_ = _data_->e;
			_data_->_tmp28_ = g_strdup_printf ("%i", _data_->_tmp27_->code);
			_data_->_tmp29_ = _data_->_tmp28_;
			_data_->_tmp30_ = _data_->e;
			_data_->_tmp31_ = _data_->_tmp30_->message;
			_data_->_tmp32_ = string_to_string (_data_->_tmp31_);
			_data_->_tmp33_ = g_strconcat ("Error while trying to reject account: ", _data_->_tmp29_, " ", _data_->_tmp32_, NULL);
			_data_->_tmp34_ = _data_->_tmp33_;
			g_warning ("Accounts.vala:541: %s", _data_->_tmp34_);
			_g_free0 (_data_->_tmp34_);
			_g_free0 (_data_->_tmp29_);
			_data_->_tmp35_ = _data_->e;
			_data_->_tmp36_ = _data_->_tmp35_->message;
			tuba_views_admin_page_accounts_account_dialog_add_toast (_data_->self, _data_->_tmp36_, (guint) 5);
			_g_error_free0 (_data_->e);
		}
		__finally0:
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
			_g_object_unref0 (_data_->req);
			_g_object_unref0 (_data_->dlg);
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error0_->message, g_quark_to_string (_data_->_inner_error0_->domain), _data_->_inner_error0_->code);
			g_clear_error (&_data_->_inner_error0_);
			g_object_unref (_data_->_async_result);
			return FALSE;
		}
		_g_object_unref0 (_data_->req);
	}
	_g_object_unref0 (_data_->dlg);
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!g_task_get_completed (_data_->_async_result)) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

static inline gpointer
tuba_views_admin_page_accounts_account_dialog_undo_row_get_instance_private (TubaViewsAdminPageAccountsAccountDialogUndoRow* self)
{
	return G_STRUCT_MEMBER_P (self, TubaViewsAdminPageAccountsAccountDialogUndoRow_private_offset);
}

static void
_tuba_views_admin_page_accounts_account_dialog_undo_row_on_undo_gtk_button_clicked (GtkButton* _sender,
                                                                                    gpointer self)
{
	tuba_views_admin_page_accounts_account_dialog_undo_row_on_undo ((TubaViewsAdminPageAccountsAccountDialogUndoRow*) self);
}

static TubaViewsAdminPageAccountsAccountDialogUndoRow*
tuba_views_admin_page_accounts_account_dialog_undo_row_construct (GType object_type,
                                                                  const gchar* title,
                                                                  const gchar* account_id,
                                                                  const gchar* endpoint)
{
	TubaViewsAdminPageAccountsAccountDialogUndoRow * self = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar** _tmp3_;
	GtkButton* _tmp4_ = NULL;
	GtkButton* _tmp5_;
	GtkButton* _tmp6_;
	g_return_val_if_fail (title != NULL, NULL);
	g_return_val_if_fail (account_id != NULL, NULL);
	g_return_val_if_fail (endpoint != NULL, NULL);
	self = (TubaViewsAdminPageAccountsAccountDialogUndoRow*) g_object_new (object_type, NULL);
	_tmp0_ = g_strdup (account_id);
	_g_free0 (self->priv->account_id);
	self->priv->account_id = _tmp0_;
	_tmp1_ = g_strdup (endpoint);
	_g_free0 (self->priv->endpoint);
	self->priv->endpoint = _tmp1_;
	gtk_list_box_row_set_activatable ((GtkListBoxRow*) self, FALSE);
	adw_preferences_row_set_title ((AdwPreferencesRow*) self, title);
	_tmp2_ = g_strdup ("destructive-action");
	_tmp3_ = g_new0 (gchar*, 1 + 1);
	_tmp3_[0] = _tmp2_;
	_tmp4_ = (GtkButton*) gtk_button_new_with_label (_ ("Undo"));
	gtk_widget_set_valign ((GtkWidget*) _tmp4_, GTK_ALIGN_CENTER);
	gtk_widget_set_css_classes ((GtkWidget*) _tmp4_, _tmp3_);
	_tmp3_ = (_vala_array_free (_tmp3_, 1, (GDestroyNotify) g_free), NULL);
	g_object_ref_sink (_tmp4_);
	_g_object_unref0 (self->priv->action_button);
	self->priv->action_button = _tmp4_;
	_tmp5_ = self->priv->action_button;
	g_signal_connect_object (_tmp5_, "clicked", (GCallback) _tuba_views_admin_page_accounts_account_dialog_undo_row_on_undo_gtk_button_clicked, self, 0);
	_tmp6_ = self->priv->action_button;
	adw_action_row_add_suffix ((AdwActionRow*) self, (GtkWidget*) _tmp6_);
	return self;
}

static TubaViewsAdminPageAccountsAccountDialogUndoRow*
tuba_views_admin_page_accounts_account_dialog_undo_row_new (const gchar* title,
                                                            const gchar* account_id,
                                                            const gchar* endpoint)
{
	return tuba_views_admin_page_accounts_account_dialog_undo_row_construct (TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_ACCOUNT_DIALOG_TYPE_UNDO_ROW, title, account_id, endpoint);
}

static void
tuba_views_admin_page_accounts_account_dialog_undo_row_on_undo (TubaViewsAdminPageAccountsAccountDialogUndoRow* self)
{
	g_return_if_fail (self != NULL);
	tuba_views_admin_page_accounts_account_dialog_undo_row_on_undo_real (self, NULL, NULL);
}

static void
tuba_views_admin_page_accounts_account_dialog_undo_row_on_undo_real_data_free (gpointer _data)
{
	TubaViewsAdminPageAccountsAccountDialogUndoRowOnUndoRealData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->self);
	g_slice_free (TubaViewsAdminPageAccountsAccountDialogUndoRowOnUndoRealData, _data_);
}

static void
tuba_views_admin_page_accounts_account_dialog_undo_row_on_undo_real (TubaViewsAdminPageAccountsAccountDialogUndoRow* self,
                                                                     GAsyncReadyCallback _callback_,
                                                                     gpointer _user_data_)
{
	TubaViewsAdminPageAccountsAccountDialogUndoRowOnUndoRealData* _data_;
	TubaViewsAdminPageAccountsAccountDialogUndoRow* _tmp0_;
	g_return_if_fail (self != NULL);
	_data_ = g_slice_new0 (TubaViewsAdminPageAccountsAccountDialogUndoRowOnUndoRealData);
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
	g_task_set_task_data (_data_->_async_result, _data_, tuba_views_admin_page_accounts_account_dialog_undo_row_on_undo_real_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	tuba_views_admin_page_accounts_account_dialog_undo_row_on_undo_real_co (_data_);
}

static void
tuba_views_admin_page_accounts_account_dialog_undo_row_on_undo_real_finish (TubaViewsAdminPageAccountsAccountDialogUndoRow* self,
                                                                            GAsyncResult* _res_)
{
	TubaViewsAdminPageAccountsAccountDialogUndoRowOnUndoRealData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
}

static void
tuba_views_admin_page_accounts_account_dialog_undo_row_on_undo_real_ready (GObject* source_object,
                                                                           GAsyncResult* _res_,
                                                                           gpointer _user_data_)
{
	TubaViewsAdminPageAccountsAccountDialogUndoRowOnUndoRealData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	tuba_views_admin_page_accounts_account_dialog_undo_row_on_undo_real_co (_data_);
}

static gboolean
tuba_views_admin_page_accounts_account_dialog_undo_row_on_undo_real_co (TubaViewsAdminPageAccountsAccountDialogUndoRowOnUndoRealData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		case 2:
		goto _state_2;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_tmp0_ = (AdwAlertDialog*) adw_alert_dialog_new (_ ("Undo this Action?"), NULL);
	g_object_ref_sink (_data_->_tmp0_);
	_data_->dlg = _data_->_tmp0_;
	_data_->_tmp1_ = _data_->dlg;
	adw_alert_dialog_add_response (_data_->_tmp1_, "no", _ ("Cancel"));
	_data_->_tmp2_ = _data_->dlg;
	adw_alert_dialog_set_response_appearance (_data_->_tmp2_, "no", ADW_RESPONSE_DEFAULT);
	_data_->_tmp3_ = _data_->dlg;
	adw_alert_dialog_add_response (_data_->_tmp3_, "yes", _ ("Undo"));
	_data_->_tmp4_ = _data_->dlg;
	adw_alert_dialog_set_response_appearance (_data_->_tmp4_, "yes", ADW_RESPONSE_DESTRUCTIVE);
	_data_->_tmp5_ = _data_->dlg;
	_data_->_state_ = 1;
	adw_alert_dialog_choose (_data_->_tmp5_, (GtkWidget*) _data_->self, NULL, tuba_views_admin_page_accounts_account_dialog_undo_row_on_undo_real_ready, _data_);
	return FALSE;
	_state_1:
	_data_->_tmp6_ = adw_alert_dialog_choose_finish (_data_->_tmp5_, _data_->_res_);
	if (g_strcmp0 (_data_->_tmp6_, "yes") == 0) {
		_data_->_tmp7_ = _data_->self->priv->action_button;
		gtk_widget_set_sensitive ((GtkWidget*) _data_->_tmp7_, FALSE);
		_data_->_tmp8_ = _data_->self->priv->account_id;
		_data_->_tmp9_ = string_to_string (_data_->_tmp8_);
		_data_->_tmp10_ = _data_->self->priv->endpoint;
		_data_->_tmp11_ = string_to_string (_data_->_tmp10_);
		_data_->_tmp12_ = g_strconcat ("/api/v1/admin/accounts/", _data_->_tmp9_, "/", _data_->_tmp11_, NULL);
		_data_->_tmp13_ = _data_->_tmp12_;
		_data_->_tmp14_ = tuba_accounts;
		_data_->_tmp15_ = tuba_account_store_get_active (_data_->_tmp14_);
		_data_->_tmp16_ = _data_->_tmp15_;
		_data_->_tmp17_ = _g_object_ref0 (_data_->_tmp16_);
		_data_->_tmp18_ = NULL;
		_data_->_tmp18_ = tuba_request_v2_new (_data_->_tmp13_, TUBA_REQUEST_V2_METHOD_POST);
		tuba_request_v2_set_account (_data_->_tmp18_, _data_->_tmp17_);
		_g_object_unref0 (_data_->_tmp17_);
		_data_->_tmp19_ = _data_->_tmp18_;
		_g_free0 (_data_->_tmp13_);
		_data_->req = _data_->_tmp19_;
		{
			_data_->_tmp20_ = _data_->req;
			_data_->_state_ = 2;
			tuba_request_v2_exec (_data_->_tmp20_, tuba_views_admin_page_accounts_account_dialog_undo_row_on_undo_real_ready, _data_);
			return FALSE;
			_state_2:
			_data_->_tmp21_ = tuba_request_v2_exec_finish (_data_->_tmp20_, _data_->_res_, NULL, &_data_->_inner_error0_);
			_data_->_tmp22_ = _data_->_tmp21_;
			_g_object_unref0 (_data_->_tmp22_);
			if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
				goto __catch0_g_error;
			}
			gtk_widget_set_visible ((GtkWidget*) _data_->self, FALSE);
			g_signal_emit (_data_->self, tuba_views_admin_page_accounts_account_dialog_undo_row_signals[TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_ACCOUNT_DIALOG_UNDO_ROW_UNDONE_SIGNAL], 0);
		}
		goto __finally0;
		__catch0_g_error:
		{
			_data_->e = _data_->_inner_error0_;
			_data_->_inner_error0_ = NULL;
			_data_->_tmp23_ = _data_->self->priv->action_button;
			gtk_widget_set_sensitive ((GtkWidget*) _data_->_tmp23_, TRUE);
			_data_->_tmp24_ = _data_->self->priv->endpoint;
			_data_->_tmp25_ = string_to_string (_data_->_tmp24_);
			_data_->_tmp26_ = _data_->e;
			_data_->_tmp27_ = g_strdup_printf ("%i", _data_->_tmp26_->code);
			_data_->_tmp28_ = _data_->_tmp27_;
			_data_->_tmp29_ = _data_->e;
			_data_->_tmp30_ = _data_->_tmp29_->message;
			_data_->_tmp31_ = string_to_string (_data_->_tmp30_);
			_data_->_tmp32_ = g_strconcat ("Error while trying to undo action using ", _data_->_tmp25_, ": ", _data_->_tmp28_, " ", _data_->_tmp31_, NULL);
			_data_->_tmp33_ = _data_->_tmp32_;
			g_warning ("Accounts.vala:445: %s", _data_->_tmp33_);
			_g_free0 (_data_->_tmp33_);
			_g_free0 (_data_->_tmp28_);
			_data_->_tmp34_ = _data_->e;
			_data_->_tmp35_ = _data_->_tmp34_->message;
			g_signal_emit (_data_->self, tuba_views_admin_page_accounts_account_dialog_undo_row_signals[TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_ACCOUNT_DIALOG_UNDO_ROW_ON_ERROR_SIGNAL], 0, _data_->_tmp35_, (guint) 5);
			_g_error_free0 (_data_->e);
		}
		__finally0:
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
			_g_object_unref0 (_data_->req);
			_g_object_unref0 (_data_->dlg);
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error0_->message, g_quark_to_string (_data_->_inner_error0_->domain), _data_->_inner_error0_->code);
			g_clear_error (&_data_->_inner_error0_);
			g_object_unref (_data_->_async_result);
			return FALSE;
		}
		_g_object_unref0 (_data_->req);
	}
	_g_object_unref0 (_data_->dlg);
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!g_task_get_completed (_data_->_async_result)) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

static void
g_cclosure_user_marshal_VOID__STRING_UINT (GClosure * closure,
                                           GValue * return_value,
                                           guint n_param_values,
                                           const GValue * param_values,
                                           gpointer invocation_hint,
                                           gpointer marshal_data)
{
	typedef void (*GMarshalFunc_VOID__STRING_UINT) (gpointer data1, const char* arg_1, guint arg_2, gpointer data2);
	register GMarshalFunc_VOID__STRING_UINT callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
	g_return_if_fail (n_param_values == 3);
	if (G_CCLOSURE_SWAP_DATA (closure)) {
		data1 = closure->data;
		data2 = param_values->data[0].v_pointer;
	} else {
		data1 = param_values->data[0].v_pointer;
		data2 = closure->data;
	}
	callback = (GMarshalFunc_VOID__STRING_UINT) (marshal_data ? marshal_data : cc->callback);
	callback (data1, g_value_get_string (param_values + 1), g_value_get_uint (param_values + 2), data2);
}

static void
tuba_views_admin_page_accounts_account_dialog_undo_row_class_init (TubaViewsAdminPageAccountsAccountDialogUndoRowClass * klass,
                                                                   gpointer klass_data)
{
	tuba_views_admin_page_accounts_account_dialog_undo_row_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaViewsAdminPageAccountsAccountDialogUndoRow_private_offset);
	G_OBJECT_CLASS (klass)->finalize = tuba_views_admin_page_accounts_account_dialog_undo_row_finalize;
	tuba_views_admin_page_accounts_account_dialog_undo_row_signals[TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_ACCOUNT_DIALOG_UNDO_ROW_ON_ERROR_SIGNAL] = g_signal_new ("on-error", TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_ACCOUNT_DIALOG_TYPE_UNDO_ROW, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__STRING_UINT, G_TYPE_NONE, 2, G_TYPE_STRING, G_TYPE_UINT);
	tuba_views_admin_page_accounts_account_dialog_undo_row_signals[TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_ACCOUNT_DIALOG_UNDO_ROW_UNDONE_SIGNAL] = g_signal_new ("undone", TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_ACCOUNT_DIALOG_TYPE_UNDO_ROW, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
}

static void
tuba_views_admin_page_accounts_account_dialog_undo_row_instance_init (TubaViewsAdminPageAccountsAccountDialogUndoRow * self,
                                                                      gpointer klass)
{
	self->priv = tuba_views_admin_page_accounts_account_dialog_undo_row_get_instance_private (self);
}

static void
tuba_views_admin_page_accounts_account_dialog_undo_row_finalize (GObject * obj)
{
	TubaViewsAdminPageAccountsAccountDialogUndoRow * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_ACCOUNT_DIALOG_TYPE_UNDO_ROW, TubaViewsAdminPageAccountsAccountDialogUndoRow);
	_g_free0 (self->priv->account_id);
	_g_free0 (self->priv->endpoint);
	_g_object_unref0 (self->priv->action_button);
	G_OBJECT_CLASS (tuba_views_admin_page_accounts_account_dialog_undo_row_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_views_admin_page_accounts_account_dialog_undo_row_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaViewsAdminPageAccountsAccountDialogUndoRowClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_views_admin_page_accounts_account_dialog_undo_row_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaViewsAdminPageAccountsAccountDialogUndoRow), 0, (GInstanceInitFunc) tuba_views_admin_page_accounts_account_dialog_undo_row_instance_init, NULL };
	GType tuba_views_admin_page_accounts_account_dialog_undo_row_type_id;
	tuba_views_admin_page_accounts_account_dialog_undo_row_type_id = g_type_register_static (adw_action_row_get_type (), "TubaViewsAdminPageAccountsAccountDialogUndoRow", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaViewsAdminPageAccountsAccountDialogUndoRow_private_offset = g_type_add_instance_private (tuba_views_admin_page_accounts_account_dialog_undo_row_type_id, sizeof (TubaViewsAdminPageAccountsAccountDialogUndoRowPrivate));
	return tuba_views_admin_page_accounts_account_dialog_undo_row_type_id;
}

static GType
tuba_views_admin_page_accounts_account_dialog_undo_row_get_type (void)
{
	static GType tuba_views_admin_page_accounts_account_dialog_undo_row_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_views_admin_page_accounts_account_dialog_undo_row_type_id__once)) {
		GType tuba_views_admin_page_accounts_account_dialog_undo_row_type_id;
		tuba_views_admin_page_accounts_account_dialog_undo_row_type_id = tuba_views_admin_page_accounts_account_dialog_undo_row_get_type_once ();
		g_once_init_leave_pointer (&tuba_views_admin_page_accounts_account_dialog_undo_row_type_id__once, tuba_views_admin_page_accounts_account_dialog_undo_row_type_id);
	}
	return tuba_views_admin_page_accounts_account_dialog_undo_row_type_id__once;
}

static void
_tuba_views_admin_page_accounts_account_dialog_show_take_action_dialog_gtk_button_clicked (GtkButton* _sender,
                                                                                           gpointer self)
{
	tuba_views_admin_page_accounts_account_dialog_show_take_action_dialog ((TubaViewsAdminPageAccountsAccountDialog*) self);
}

static void
_tuba_views_admin_page_accounts_account_dialog_on_close_gtk_button_clicked (GtkButton* _sender,
                                                                            gpointer self)
{
	tuba_views_admin_page_accounts_account_dialog_on_close ((TubaViewsAdminPageAccountsAccountDialog*) self);
}

static GObject *
tuba_views_admin_page_accounts_account_dialog_constructor (GType type,
                                                           guint n_construct_properties,
                                                           GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	TubaViewsAdminPageAccountsAccountDialog * self;
	AdwPreferencesPage* _tmp0_;
	AdwPreferencesPage* _tmp1_;
	GtkWidget* _tmp2_;
	AdwToastOverlay* _tmp3_ = NULL;
	AdwToolbarView* toolbarview = NULL;
	AdwToastOverlay* _tmp4_;
	GtkWidget* _tmp5_;
	AdwToolbarView* _tmp6_ = NULL;
	AdwHeaderBar* headerbar = NULL;
	AdwHeaderBar* _tmp7_ = NULL;
	GtkButton* take_action_button = NULL;
	gchar* _tmp8_;
	gchar** _tmp9_;
	GtkButton* _tmp10_ = NULL;
	GtkButton* _tmp11_;
	AdwHeaderBar* _tmp12_;
	GtkButton* _tmp13_;
	GtkButton* cancel_button = NULL;
	GtkButton* _tmp14_;
	GtkButton* _tmp15_;
	AdwHeaderBar* _tmp16_;
	GtkButton* _tmp17_;
	AdwToolbarView* _tmp18_;
	AdwHeaderBar* _tmp19_;
	AdwToolbarView* _tmp20_;
	parent_class = G_OBJECT_CLASS (tuba_views_admin_page_accounts_account_dialog_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_TYPE_ACCOUNT_DIALOG, TubaViewsAdminPageAccountsAccountDialog);
	adw_dialog_set_content_width ((AdwDialog*) self, 460);
	adw_dialog_set_content_height ((AdwDialog*) self, 510);
	adw_dialog_set_can_close ((AdwDialog*) self, FALSE);
	_tmp0_ = (AdwPreferencesPage*) adw_preferences_page_new ();
	g_object_ref_sink (_tmp0_);
	_g_object_unref0 (self->priv->page);
	self->priv->page = _tmp0_;
	_tmp1_ = self->priv->page;
	_tmp2_ = _g_object_ref0 ((GtkWidget*) _tmp1_);
	_tmp3_ = (AdwToastOverlay*) adw_toast_overlay_new ();
	gtk_widget_set_vexpand ((GtkWidget*) _tmp3_, TRUE);
	gtk_widget_set_hexpand ((GtkWidget*) _tmp3_, TRUE);
	adw_toast_overlay_set_child (_tmp3_, _tmp2_);
	_g_object_unref0 (_tmp2_);
	g_object_ref_sink (_tmp3_);
	_g_object_unref0 (self->priv->toast_overlay);
	self->priv->toast_overlay = _tmp3_;
	_tmp4_ = self->priv->toast_overlay;
	_tmp5_ = _g_object_ref0 ((GtkWidget*) _tmp4_);
	_tmp6_ = (AdwToolbarView*) adw_toolbar_view_new ();
	adw_toolbar_view_set_content (_tmp6_, _tmp5_);
	_g_object_unref0 (_tmp5_);
	gtk_widget_set_valign ((GtkWidget*) _tmp6_, GTK_ALIGN_CENTER);
	g_object_ref_sink (_tmp6_);
	toolbarview = _tmp6_;
	_tmp7_ = (AdwHeaderBar*) adw_header_bar_new ();
	adw_header_bar_set_show_end_title_buttons (_tmp7_, FALSE);
	adw_header_bar_set_show_start_title_buttons (_tmp7_, FALSE);
	g_object_ref_sink (_tmp7_);
	headerbar = _tmp7_;
	_tmp8_ = g_strdup ("destructive-action");
	_tmp9_ = g_new0 (gchar*, 1 + 1);
	_tmp9_[0] = _tmp8_;
	_tmp10_ = (GtkButton*) gtk_button_new_with_label (_ ("Take Action"));
	gtk_widget_set_css_classes ((GtkWidget*) _tmp10_, _tmp9_);
	_tmp9_ = (_vala_array_free (_tmp9_, 1, (GDestroyNotify) g_free), NULL);
	g_object_ref_sink (_tmp10_);
	take_action_button = _tmp10_;
	_tmp11_ = take_action_button;
	g_signal_connect_object (_tmp11_, "clicked", (GCallback) _tuba_views_admin_page_accounts_account_dialog_show_take_action_dialog_gtk_button_clicked, self, 0);
	_tmp12_ = headerbar;
	_tmp13_ = take_action_button;
	adw_header_bar_pack_end (_tmp12_, (GtkWidget*) _tmp13_);
	_tmp14_ = (GtkButton*) gtk_button_new_with_label (_ ("Cancel"));
	g_object_ref_sink (_tmp14_);
	cancel_button = _tmp14_;
	_tmp15_ = cancel_button;
	g_signal_connect_object (_tmp15_, "clicked", (GCallback) _tuba_views_admin_page_accounts_account_dialog_on_close_gtk_button_clicked, self, 0);
	_tmp16_ = headerbar;
	_tmp17_ = cancel_button;
	adw_header_bar_pack_start (_tmp16_, (GtkWidget*) _tmp17_);
	_tmp18_ = toolbarview;
	_tmp19_ = headerbar;
	adw_toolbar_view_add_top_bar (_tmp18_, (GtkWidget*) _tmp19_);
	_tmp20_ = toolbarview;
	adw_dialog_set_child ((AdwDialog*) self, (GtkWidget*) _tmp20_);
	_g_object_unref0 (cancel_button);
	_g_object_unref0 (take_action_button);
	_g_object_unref0 (headerbar);
	_g_object_unref0 (toolbarview);
	return obj;
}

static void
tuba_views_admin_page_accounts_account_dialog_class_init (TubaViewsAdminPageAccountsAccountDialogClass * klass,
                                                          gpointer klass_data)
{
	tuba_views_admin_page_accounts_account_dialog_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaViewsAdminPageAccountsAccountDialog_private_offset);
	G_OBJECT_CLASS (klass)->constructor = tuba_views_admin_page_accounts_account_dialog_constructor;
	G_OBJECT_CLASS (klass)->finalize = tuba_views_admin_page_accounts_account_dialog_finalize;
	tuba_views_admin_page_accounts_account_dialog_signals[TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_ACCOUNT_DIALOG_REFRESH_SIGNAL] = g_signal_new ("refresh", TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_TYPE_ACCOUNT_DIALOG, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
}

static void
tuba_views_admin_page_accounts_account_dialog_instance_init (TubaViewsAdminPageAccountsAccountDialog * self,
                                                             gpointer klass)
{
	self->priv = tuba_views_admin_page_accounts_account_dialog_get_instance_private (self);
	self->priv->approval_row = NULL;
	self->priv->should_refresh = FALSE;
}

static void
tuba_views_admin_page_accounts_account_dialog_finalize (GObject * obj)
{
	TubaViewsAdminPageAccountsAccountDialog * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_TYPE_ACCOUNT_DIALOG, TubaViewsAdminPageAccountsAccountDialog);
	g_debug ("Accounts.vala:223: Destroying AccountDialog");
	_g_object_unref0 (self->priv->page);
	_g_object_unref0 (self->priv->toast_overlay);
	_g_free0 (self->priv->account_id);
	_g_free0 (self->priv->account_handle);
	_g_object_unref0 (self->priv->approval_row);
	G_OBJECT_CLASS (tuba_views_admin_page_accounts_account_dialog_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_views_admin_page_accounts_account_dialog_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaViewsAdminPageAccountsAccountDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_views_admin_page_accounts_account_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaViewsAdminPageAccountsAccountDialog), 0, (GInstanceInitFunc) tuba_views_admin_page_accounts_account_dialog_instance_init, NULL };
	GType tuba_views_admin_page_accounts_account_dialog_type_id;
	tuba_views_admin_page_accounts_account_dialog_type_id = g_type_register_static (adw_dialog_get_type (), "TubaViewsAdminPageAccountsAccountDialog", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaViewsAdminPageAccountsAccountDialog_private_offset = g_type_add_instance_private (tuba_views_admin_page_accounts_account_dialog_type_id, sizeof (TubaViewsAdminPageAccountsAccountDialogPrivate));
	return tuba_views_admin_page_accounts_account_dialog_type_id;
}

static GType
tuba_views_admin_page_accounts_account_dialog_get_type (void)
{
	static GType tuba_views_admin_page_accounts_account_dialog_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_views_admin_page_accounts_account_dialog_type_id__once)) {
		GType tuba_views_admin_page_accounts_account_dialog_type_id;
		tuba_views_admin_page_accounts_account_dialog_type_id = tuba_views_admin_page_accounts_account_dialog_get_type_once ();
		g_once_init_leave_pointer (&tuba_views_admin_page_accounts_account_dialog_type_id__once, tuba_views_admin_page_accounts_account_dialog_type_id);
	}
	return tuba_views_admin_page_accounts_account_dialog_type_id__once;
}

static void
_tuba_views_admin_page_accounts_on_search_button_toggle_gtk_toggle_button_toggled (GtkToggleButton* _sender,
                                                                                   gpointer self)
{
	tuba_views_admin_page_accounts_on_search_button_toggle ((TubaViewsAdminPageAccounts*) self);
}

static void
_vala_GValue_free (GValue* self)
{
	g_boxed_free (G_TYPE_VALUE, self);
}

static void
_tuba_views_admin_page_accounts_dropdown_signal_gtk_signal_list_item_factory_bind (GtkSignalListItemFactory* _sender,
                                                                                   GObject* object,
                                                                                   gpointer self)
{
	tuba_views_admin_page_accounts_dropdown_signal ((TubaViewsAdminPageAccounts*) self, object);
}

static void
_tuba_views_admin_page_accounts_on_search_g_object_notify (GObject* _sender,
                                                           GParamSpec* pspec,
                                                           gpointer self)
{
	tuba_views_admin_page_accounts_on_search ((TubaViewsAdminPageAccounts*) self);
}

static void
_tuba_views_admin_page_accounts_on_search_gtk_entry_activate (GtkEntry* _sender,
                                                              gpointer self)
{
	tuba_views_admin_page_accounts_on_search ((TubaViewsAdminPageAccounts*) self);
}

static void
_tuba_views_admin_page_accounts_show_account_dialog_tuba_views_admin_timeline_accounts_on_open_account (TubaViewsAdminTimelineAccounts* _sender,
                                                                                                        TubaAPIAdminAccount* account,
                                                                                                        gpointer self)
{
	tuba_views_admin_page_accounts_show_account_dialog ((TubaViewsAdminPageAccounts*) self, account);
}

static void
_tuba_views_admin_page_base_on_error_tuba_views_admin_timeline_pagination_timeline_on_error (TubaViewsAdminTimelinePaginationTimeline* _sender,
                                                                                             gint code,
                                                                                             const gchar* message,
                                                                                             gpointer self)
{
	tuba_views_admin_page_base_on_error ((TubaViewsAdminPageBase*) self, code, message);
}

static GObject *
tuba_views_admin_page_accounts_constructor (GType type,
                                            guint n_construct_properties,
                                            GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	TubaViewsAdminPageAccounts * self;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar** _tmp2_;
	gchar* _tmp3_;
	GtkToggleButton* _tmp4_ = NULL;
	GtkToggleButton* _tmp5_;
	AdwHeaderBar* _tmp6_;
	GtkToggleButton* _tmp7_;
	GtkBox* revealer_box = NULL;
	GtkBox* _tmp8_ = NULL;
	GtkBox* entry_box_1 = NULL;
	GtkBox* _tmp9_;
	GtkBox* entry_box_2 = NULL;
	GtkBox* _tmp10_;
	GtkBox* dropdown_box_1 = NULL;
	GtkBox* _tmp11_ = NULL;
	GtkBox* _tmp12_;
	GtkBox* _tmp13_;
	GtkBox* _tmp14_;
	GtkBox* _tmp15_;
	GtkBox* _tmp16_;
	GtkBox* _tmp17_;
	AdwBreakpointBin* breakpoint_bin = NULL;
	GtkBox* _tmp18_;
	GtkWidget* _tmp19_;
	AdwBreakpointBin* _tmp20_ = NULL;
	AdwBreakpointCondition* condition = NULL;
	AdwBreakpointCondition* _tmp21_;
	AdwBreakpoint* breakpoint = NULL;
	AdwBreakpointCondition* _tmp22_;
	AdwBreakpoint* _tmp23_;
	AdwBreakpoint* _tmp24_;
	GtkBox* _tmp25_;
	GValue* _tmp26_ = NULL;
	AdwBreakpoint* _tmp27_;
	GtkBox* _tmp28_;
	GValue* _tmp29_ = NULL;
	AdwBreakpoint* _tmp30_;
	GtkBox* _tmp31_;
	GValue* _tmp32_ = NULL;
	AdwBreakpoint* _tmp33_;
	GtkBox* _tmp34_;
	GValue* _tmp35_ = NULL;
	AdwBreakpointBin* _tmp36_;
	AdwBreakpoint* _tmp37_;
	AdwBreakpoint* _tmp38_;
	GtkSignalListItemFactory* signallistitemfactory_location = NULL;
	GtkSignalListItemFactory* _tmp39_;
	GtkSignalListItemFactory* _tmp40_;
	GListStore* location_model = NULL;
	GListStore* _tmp41_;
	GListStore* _tmp42_;
	TubaViewsAdminPageAccountsDropDownStringEntry* _tmp43_;
	TubaViewsAdminPageAccountsDropDownStringEntry* _tmp44_;
	TubaViewsAdminPageAccountsDropDownStringEntry* _tmp45_;
	GObject** _tmp46_;
	GObject** _tmp47_;
	gint _tmp47__length1;
	GListStore* _tmp48_;
	GListModel* _tmp49_;
	gchar* _tmp50_;
	GtkSignalListItemFactory* _tmp51_;
	GtkListItemFactory* _tmp52_;
	GtkDropDown* _tmp53_ = NULL;
	GtkDropDown* _tmp54_;
	GtkBox* _tmp55_;
	GtkDropDown* _tmp56_;
	GtkSignalListItemFactory* signallistitemfactory_moderation = NULL;
	GtkSignalListItemFactory* _tmp57_;
	GtkSignalListItemFactory* _tmp58_;
	GListStore* moderation_model = NULL;
	GListStore* _tmp59_;
	GListStore* _tmp60_;
	TubaViewsAdminPageAccountsDropDownStringEntry* _tmp61_;
	TubaViewsAdminPageAccountsDropDownStringEntry* _tmp62_;
	TubaViewsAdminPageAccountsDropDownStringEntry* _tmp63_;
	TubaViewsAdminPageAccountsDropDownStringEntry* _tmp64_;
	TubaViewsAdminPageAccountsDropDownStringEntry* _tmp65_;
	TubaViewsAdminPageAccountsDropDownStringEntry* _tmp66_;
	GObject** _tmp67_;
	GObject** _tmp68_;
	gint _tmp68__length1;
	GListStore* _tmp69_;
	GListModel* _tmp70_;
	gchar* _tmp71_;
	GtkSignalListItemFactory* _tmp72_;
	GtkListItemFactory* _tmp73_;
	GtkDropDown* _tmp74_ = NULL;
	GtkDropDown* _tmp75_;
	GtkBox* _tmp76_;
	GtkDropDown* _tmp77_;
	gchar* _tmp78_;
	GtkEntry* _tmp79_ = NULL;
	GtkEntry* _tmp80_;
	GtkBox* _tmp81_;
	GtkEntry* _tmp82_;
	gchar* _tmp83_;
	GtkEntry* _tmp84_ = NULL;
	GtkEntry* _tmp85_;
	GtkBox* _tmp86_;
	GtkEntry* _tmp87_;
	gchar* _tmp88_;
	GtkEntry* _tmp89_ = NULL;
	GtkEntry* _tmp90_;
	GtkBox* _tmp91_;
	GtkEntry* _tmp92_;
	gchar* _tmp93_;
	GtkEntry* _tmp94_ = NULL;
	GtkEntry* _tmp95_;
	GtkBox* _tmp96_;
	GtkEntry* _tmp97_;
	AdwBreakpointBin* _tmp98_;
	GtkWidget* _tmp99_;
	GtkRevealer* _tmp100_ = NULL;
	AdwToolbarView* _tmp101_;
	GtkRevealer* _tmp102_;
	TubaViewsAdminTimelineAccounts* _tmp103_;
	TubaViewsAdminTimelineAccounts* _tmp104_;
	TubaViewsAdminTimelineAccounts* _tmp105_;
	TubaViewsAdminTimelineAccounts* _tmp106_;
	TubaViewsAdminTimelineAccounts* _tmp107_;
	parent_class = G_OBJECT_CLASS (tuba_views_admin_page_accounts_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_VIEWS_ADMIN_PAGE_TYPE_ACCOUNTS, TubaViewsAdminPageAccounts);
	adw_navigation_page_set_title ((AdwNavigationPage*) self, _ ("Accounts"));
	_tmp0_ = g_strdup (_ ("Search"));
	_tmp1_ = g_strdup ("flat");
	_tmp2_ = g_new0 (gchar*, 1 + 1);
	_tmp2_[0] = _tmp1_;
	_tmp3_ = g_strdup ("tuba-loupe-large-symbolic");
	_tmp4_ = (GtkToggleButton*) gtk_toggle_button_new ();
	gtk_widget_set_tooltip_text ((GtkWidget*) _tmp4_, _tmp0_);
	_g_free0 (_tmp0_);
	gtk_widget_set_css_classes ((GtkWidget*) _tmp4_, _tmp2_);
	_tmp2_ = (_vala_array_free (_tmp2_, 1, (GDestroyNotify) g_free), NULL);
	gtk_button_set_icon_name ((GtkButton*) _tmp4_, _tmp3_);
	_g_free0 (_tmp3_);
	g_object_ref_sink (_tmp4_);
	_g_object_unref0 (self->priv->search_button);
	self->priv->search_button = _tmp4_;
	_tmp5_ = self->priv->search_button;
	g_signal_connect_object (_tmp5_, "toggled", (GCallback) _tuba_views_admin_page_accounts_on_search_button_toggle_gtk_toggle_button_toggled, self, 0);
	_tmp6_ = ((TubaViewsAdminPageBase*) self)->headerbar;
	_tmp7_ = self->priv->search_button;
	adw_header_bar_pack_end (_tmp6_, (GtkWidget*) _tmp7_);
	_tmp8_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
	gtk_widget_set_margin_start ((GtkWidget*) _tmp8_, 6);
	gtk_widget_set_margin_end ((GtkWidget*) _tmp8_, 6);
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp8_, 3);
	gtk_widget_set_halign ((GtkWidget*) _tmp8_, GTK_ALIGN_CENTER);
	g_object_ref_sink (_tmp8_);
	revealer_box = _tmp8_;
	_tmp9_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
	g_object_ref_sink (_tmp9_);
	entry_box_1 = _tmp9_;
	_tmp10_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
	g_object_ref_sink (_tmp10_);
	entry_box_2 = _tmp10_;
	_tmp11_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
	gtk_box_set_homogeneous (_tmp11_, TRUE);
	g_object_ref_sink (_tmp11_);
	dropdown_box_1 = _tmp11_;
	_tmp12_ = revealer_box;
	_tmp13_ = dropdown_box_1;
	gtk_box_append (_tmp12_, (GtkWidget*) _tmp13_);
	_tmp14_ = revealer_box;
	_tmp15_ = entry_box_1;
	gtk_box_append (_tmp14_, (GtkWidget*) _tmp15_);
	_tmp16_ = revealer_box;
	_tmp17_ = entry_box_2;
	gtk_box_append (_tmp16_, (GtkWidget*) _tmp17_);
	_tmp18_ = revealer_box;
	_tmp19_ = _g_object_ref0 ((GtkWidget*) _tmp18_);
	_tmp20_ = (AdwBreakpointBin*) adw_breakpoint_bin_new ();
	adw_breakpoint_bin_set_child (_tmp20_, _tmp19_);
	_g_object_unref0 (_tmp19_);
	g_object_set ((GtkWidget*) _tmp20_, "width-request", 5, NULL);
	g_object_set ((GtkWidget*) _tmp20_, "height-request", 5, NULL);
	g_object_ref_sink (_tmp20_);
	breakpoint_bin = _tmp20_;
	_tmp21_ = adw_breakpoint_condition_new_length (ADW_BREAKPOINT_CONDITION_MAX_WIDTH, (gdouble) 450, ADW_LENGTH_UNIT_SP);
	condition = _tmp21_;
	_tmp22_ = condition;
	condition = NULL;
	_tmp23_ = adw_breakpoint_new (_tmp22_);
	breakpoint = _tmp23_;
	_tmp24_ = breakpoint;
	_tmp25_ = revealer_box;
	_tmp26_ = g_new0 (GValue, 1);
	g_value_init (_tmp26_, gtk_align_get_type ());
	g_value_set_enum (_tmp26_, GTK_ALIGN_FILL);
	adw_breakpoint_add_setter (_tmp24_, (GObject*) _tmp25_, "halign", _tmp26_);
	__vala_GValue_free0 (_tmp26_);
	_tmp27_ = breakpoint;
	_tmp28_ = entry_box_1;
	_tmp29_ = g_new0 (GValue, 1);
	g_value_init (_tmp29_, gtk_orientation_get_type ());
	g_value_set_enum (_tmp29_, GTK_ORIENTATION_VERTICAL);
	adw_breakpoint_add_setter (_tmp27_, (GObject*) _tmp28_, "orientation", _tmp29_);
	__vala_GValue_free0 (_tmp29_);
	_tmp30_ = breakpoint;
	_tmp31_ = entry_box_2;
	_tmp32_ = g_new0 (GValue, 1);
	g_value_init (_tmp32_, gtk_orientation_get_type ());
	g_value_set_enum (_tmp32_, GTK_ORIENTATION_VERTICAL);
	adw_breakpoint_add_setter (_tmp30_, (GObject*) _tmp31_, "orientation", _tmp32_);
	__vala_GValue_free0 (_tmp32_);
	_tmp33_ = breakpoint;
	_tmp34_ = dropdown_box_1;
	_tmp35_ = g_new0 (GValue, 1);
	g_value_init (_tmp35_, gtk_orientation_get_type ());
	g_value_set_enum (_tmp35_, GTK_ORIENTATION_VERTICAL);
	adw_breakpoint_add_setter (_tmp33_, (GObject*) _tmp34_, "orientation", _tmp35_);
	__vala_GValue_free0 (_tmp35_);
	_tmp36_ = breakpoint_bin;
	_tmp37_ = breakpoint;
	_tmp38_ = _g_object_ref0 (_tmp37_);
	adw_breakpoint_bin_add_breakpoint (_tmp36_, _tmp38_);
	_tmp39_ = (GtkSignalListItemFactory*) gtk_signal_list_item_factory_new ();
	signallistitemfactory_location = _tmp39_;
	_tmp40_ = signallistitemfactory_location;
	g_signal_connect_object (_tmp40_, "bind", (GCallback) _tuba_views_admin_page_accounts_dropdown_signal_gtk_signal_list_item_factory_bind, self, 0);
	_tmp41_ = g_list_store_new (TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_TYPE_DROP_DOWN_STRING_ENTRY);
	location_model = _tmp41_;
	_tmp42_ = location_model;
	_tmp43_ = tuba_views_admin_page_accounts_drop_down_string_entry_new ("all", _ ("All"));
	_tmp44_ = tuba_views_admin_page_accounts_drop_down_string_entry_new ("local", _ ("Local"));
	_tmp45_ = tuba_views_admin_page_accounts_drop_down_string_entry_new ("remote", _ ("Remote"));
	_tmp46_ = g_new0 (GObject*, 3 + 1);
	_tmp46_[0] = (GObject*) _tmp43_;
	_tmp46_[1] = (GObject*) _tmp44_;
	_tmp46_[2] = (GObject*) _tmp45_;
	_tmp47_ = _tmp46_;
	_tmp47__length1 = 3;
	g_list_store_splice (_tmp42_, (guint) 0, (guint) 0, _tmp47_, (guint) 3);
	_tmp47_ = (_vala_array_free (_tmp47_, _tmp47__length1, (GDestroyNotify) g_object_unref), NULL);
	_tmp48_ = location_model;
	_tmp49_ = _g_object_ref0 ((GListModel*) _tmp48_);
	_tmp50_ = g_strdup (_ ("Location"));
	_tmp51_ = signallistitemfactory_location;
	_tmp52_ = _g_object_ref0 ((GtkListItemFactory*) _tmp51_);
	_tmp53_ = (GtkDropDown*) gtk_drop_down_new (_tmp49_, NULL);
	gtk_widget_set_tooltip_text ((GtkWidget*) _tmp53_, _tmp50_);
	_g_free0 (_tmp50_);
	gtk_drop_down_set_factory (_tmp53_, _tmp52_);
	_g_object_unref0 (_tmp52_);
	gtk_drop_down_set_show_arrow (_tmp53_, TRUE);
	gtk_widget_set_hexpand ((GtkWidget*) _tmp53_, TRUE);
	g_object_ref_sink (_tmp53_);
	_g_object_unref0 (self->priv->location_dropdown);
	self->priv->location_dropdown = _tmp53_;
	_tmp54_ = self->priv->location_dropdown;
	g_signal_connect_object ((GObject*) _tmp54_, "notify::selected", (GCallback) _tuba_views_admin_page_accounts_on_search_g_object_notify, self, 0);
	_tmp55_ = dropdown_box_1;
	_tmp56_ = self->priv->location_dropdown;
	gtk_box_append (_tmp55_, (GtkWidget*) _tmp56_);
	_tmp57_ = (GtkSignalListItemFactory*) gtk_signal_list_item_factory_new ();
	signallistitemfactory_moderation = _tmp57_;
	_tmp58_ = signallistitemfactory_moderation;
	g_signal_connect_object (_tmp58_, "bind", (GCallback) _tuba_views_admin_page_accounts_dropdown_signal_gtk_signal_list_item_factory_bind, self, 0);
	_tmp59_ = g_list_store_new (TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_TYPE_DROP_DOWN_STRING_ENTRY);
	moderation_model = _tmp59_;
	_tmp60_ = moderation_model;
	_tmp61_ = tuba_views_admin_page_accounts_drop_down_string_entry_new ("all", _ ("All"));
	_tmp62_ = tuba_views_admin_page_accounts_drop_down_string_entry_new ("active", _ ("Active"));
	_tmp63_ = tuba_views_admin_page_accounts_drop_down_string_entry_new ("silenced", _ ("Limited"));
	_tmp64_ = tuba_views_admin_page_accounts_drop_down_string_entry_new ("disabled", _ ("Disabled"));
	_tmp65_ = tuba_views_admin_page_accounts_drop_down_string_entry_new ("suspended", _ ("Suspended"));
	_tmp66_ = tuba_views_admin_page_accounts_drop_down_string_entry_new ("pending", _ ("Pending"));
	_tmp67_ = g_new0 (GObject*, 6 + 1);
	_tmp67_[0] = (GObject*) _tmp61_;
	_tmp67_[1] = (GObject*) _tmp62_;
	_tmp67_[2] = (GObject*) _tmp63_;
	_tmp67_[3] = (GObject*) _tmp64_;
	_tmp67_[4] = (GObject*) _tmp65_;
	_tmp67_[5] = (GObject*) _tmp66_;
	_tmp68_ = _tmp67_;
	_tmp68__length1 = 6;
	g_list_store_splice (_tmp60_, (guint) 0, (guint) 0, _tmp68_, (guint) 6);
	_tmp68_ = (_vala_array_free (_tmp68_, _tmp68__length1, (GDestroyNotify) g_object_unref), NULL);
	_tmp69_ = moderation_model;
	_tmp70_ = _g_object_ref0 ((GListModel*) _tmp69_);
	_tmp71_ = g_strdup (_ ("Moderation"));
	_tmp72_ = signallistitemfactory_moderation;
	_tmp73_ = _g_object_ref0 ((GtkListItemFactory*) _tmp72_);
	_tmp74_ = (GtkDropDown*) gtk_drop_down_new (_tmp70_, NULL);
	gtk_widget_set_tooltip_text ((GtkWidget*) _tmp74_, _tmp71_);
	_g_free0 (_tmp71_);
	gtk_drop_down_set_factory (_tmp74_, _tmp73_);
	_g_object_unref0 (_tmp73_);
	gtk_drop_down_set_show_arrow (_tmp74_, TRUE);
	gtk_widget_set_hexpand ((GtkWidget*) _tmp74_, TRUE);
	g_object_ref_sink (_tmp74_);
	_g_object_unref0 (self->priv->moderation_dropdown);
	self->priv->moderation_dropdown = _tmp74_;
	_tmp75_ = self->priv->moderation_dropdown;
	g_signal_connect_object ((GObject*) _tmp75_, "notify::selected", (GCallback) _tuba_views_admin_page_accounts_on_search_g_object_notify, self, 0);
	_tmp76_ = dropdown_box_1;
	_tmp77_ = self->priv->moderation_dropdown;
	gtk_box_append (_tmp76_, (GtkWidget*) _tmp77_);
	_tmp78_ = g_strdup (_ ("Username"));
	_tmp79_ = (GtkEntry*) gtk_entry_new ();
	gtk_entry_set_input_purpose (_tmp79_, GTK_INPUT_PURPOSE_URL);
	gtk_entry_set_placeholder_text (_tmp79_, _tmp78_);
	_g_free0 (_tmp78_);
	g_object_ref_sink (_tmp79_);
	_g_object_unref0 (self->priv->username_entry);
	self->priv->username_entry = _tmp79_;
	_tmp80_ = self->priv->username_entry;
	g_signal_connect_object (_tmp80_, "activate", (GCallback) _tuba_views_admin_page_accounts_on_search_gtk_entry_activate, self, 0);
	_tmp81_ = entry_box_1;
	_tmp82_ = self->priv->username_entry;
	gtk_box_append (_tmp81_, (GtkWidget*) _tmp82_);
	_tmp83_ = g_strdup (_ ("Display Name"));
	_tmp84_ = (GtkEntry*) gtk_entry_new ();
	gtk_entry_set_input_purpose (_tmp84_, GTK_INPUT_PURPOSE_URL);
	gtk_entry_set_placeholder_text (_tmp84_, _tmp83_);
	_g_free0 (_tmp83_);
	g_object_ref_sink (_tmp84_);
	_g_object_unref0 (self->priv->display_name_entry);
	self->priv->display_name_entry = _tmp84_;
	_tmp85_ = self->priv->display_name_entry;
	g_signal_connect_object (_tmp85_, "activate", (GCallback) _tuba_views_admin_page_accounts_on_search_gtk_entry_activate, self, 0);
	_tmp86_ = entry_box_1;
	_tmp87_ = self->priv->display_name_entry;
	gtk_box_append (_tmp86_, (GtkWidget*) _tmp87_);
	_tmp88_ = g_strdup (_ ("E-mail"));
	_tmp89_ = (GtkEntry*) gtk_entry_new ();
	gtk_entry_set_input_purpose (_tmp89_, GTK_INPUT_PURPOSE_URL);
	gtk_entry_set_placeholder_text (_tmp89_, _tmp88_);
	_g_free0 (_tmp88_);
	g_object_ref_sink (_tmp89_);
	_g_object_unref0 (self->priv->email_entry);
	self->priv->email_entry = _tmp89_;
	_tmp90_ = self->priv->email_entry;
	g_signal_connect_object (_tmp90_, "activate", (GCallback) _tuba_views_admin_page_accounts_on_search_gtk_entry_activate, self, 0);
	_tmp91_ = entry_box_2;
	_tmp92_ = self->priv->email_entry;
	gtk_box_append (_tmp91_, (GtkWidget*) _tmp92_);
	_tmp93_ = g_strdup ("IP");
	_tmp94_ = (GtkEntry*) gtk_entry_new ();
	gtk_entry_set_input_purpose (_tmp94_, GTK_INPUT_PURPOSE_URL);
	gtk_entry_set_placeholder_text (_tmp94_, _tmp93_);
	_g_free0 (_tmp93_);
	g_object_ref_sink (_tmp94_);
	_g_object_unref0 (self->priv->ip_entry);
	self->priv->ip_entry = _tmp94_;
	_tmp95_ = self->priv->ip_entry;
	g_signal_connect_object (_tmp95_, "activate", (GCallback) _tuba_views_admin_page_accounts_on_search_gtk_entry_activate, self, 0);
	_tmp96_ = entry_box_2;
	_tmp97_ = self->priv->ip_entry;
	gtk_box_append (_tmp96_, (GtkWidget*) _tmp97_);
	_tmp98_ = breakpoint_bin;
	_tmp99_ = _g_object_ref0 ((GtkWidget*) _tmp98_);
	_tmp100_ = (GtkRevealer*) gtk_revealer_new ();
	gtk_revealer_set_child (_tmp100_, _tmp99_);
	_g_object_unref0 (_tmp99_);
	g_object_ref_sink (_tmp100_);
	_g_object_unref0 (self->priv->revealer);
	self->priv->revealer = _tmp100_;
	_tmp101_ = ((TubaViewsAdminPageBase*) self)->toolbar_view;
	_tmp102_ = self->priv->revealer;
	adw_toolbar_view_add_top_bar (_tmp101_, (GtkWidget*) _tmp102_);
	_tmp103_ = tuba_views_admin_timeline_accounts_new ();
	g_object_ref_sink (_tmp103_);
	_g_object_unref0 (self->priv->pagination_timeline);
	self->priv->pagination_timeline = _tmp103_;
	_tmp104_ = self->priv->pagination_timeline;
	g_signal_connect_object (_tmp104_, "on-open-account", (GCallback) _tuba_views_admin_page_accounts_show_account_dialog_tuba_views_admin_timeline_accounts_on_open_account, self, 0);
	_tmp105_ = self->priv->pagination_timeline;
	g_signal_connect_object ((TubaViewsAdminTimelinePaginationTimeline*) _tmp105_, "on-error", (GCallback) _tuba_views_admin_page_base_on_error_tuba_views_admin_timeline_pagination_timeline_on_error, (TubaViewsAdminPageBase*) self, 0);
	_tmp106_ = self->priv->pagination_timeline;
	g_object_bind_property_with_closures ((GObject*) _tmp106_, "working", (GObject*) self, "spinning", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)));
	_tmp107_ = self->priv->pagination_timeline;
	tuba_views_admin_page_base_set_page ((TubaViewsAdminPageBase*) self, (GtkWidget*) _tmp107_);
	tuba_views_admin_page_accounts_refresh (self);
	_g_object_unref0 (moderation_model);
	_g_object_unref0 (signallistitemfactory_moderation);
	_g_object_unref0 (location_model);
	_g_object_unref0 (signallistitemfactory_location);
	_g_object_unref0 (breakpoint);
	_adw_breakpoint_condition_free0 (condition);
	_g_object_unref0 (breakpoint_bin);
	_g_object_unref0 (dropdown_box_1);
	_g_object_unref0 (entry_box_2);
	_g_object_unref0 (entry_box_1);
	_g_object_unref0 (revealer_box);
	return obj;
}

static void
tuba_views_admin_page_accounts_class_init (TubaViewsAdminPageAccountsClass * klass,
                                           gpointer klass_data)
{
	tuba_views_admin_page_accounts_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaViewsAdminPageAccounts_private_offset);
	G_OBJECT_CLASS (klass)->constructor = tuba_views_admin_page_accounts_constructor;
	G_OBJECT_CLASS (klass)->finalize = tuba_views_admin_page_accounts_finalize;
}

static void
tuba_views_admin_page_accounts_instance_init (TubaViewsAdminPageAccounts * self,
                                              gpointer klass)
{
	self->priv = tuba_views_admin_page_accounts_get_instance_private (self);
}

static void
tuba_views_admin_page_accounts_finalize (GObject * obj)
{
	TubaViewsAdminPageAccounts * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_VIEWS_ADMIN_PAGE_TYPE_ACCOUNTS, TubaViewsAdminPageAccounts);
	_g_object_unref0 (self->priv->username_entry);
	_g_object_unref0 (self->priv->display_name_entry);
	_g_object_unref0 (self->priv->ip_entry);
	_g_object_unref0 (self->priv->email_entry);
	_g_object_unref0 (self->priv->pagination_timeline);
	_g_object_unref0 (self->priv->revealer);
	_g_object_unref0 (self->priv->search_button);
	_g_object_unref0 (self->priv->location_dropdown);
	_g_object_unref0 (self->priv->moderation_dropdown);
	G_OBJECT_CLASS (tuba_views_admin_page_accounts_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_views_admin_page_accounts_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaViewsAdminPageAccountsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_views_admin_page_accounts_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaViewsAdminPageAccounts), 0, (GInstanceInitFunc) tuba_views_admin_page_accounts_instance_init, NULL };
	GType tuba_views_admin_page_accounts_type_id;
	tuba_views_admin_page_accounts_type_id = g_type_register_static (TUBA_VIEWS_ADMIN_PAGE_TYPE_BASE, "TubaViewsAdminPageAccounts", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaViewsAdminPageAccounts_private_offset = g_type_add_instance_private (tuba_views_admin_page_accounts_type_id, sizeof (TubaViewsAdminPageAccountsPrivate));
	return tuba_views_admin_page_accounts_type_id;
}

GType
tuba_views_admin_page_accounts_get_type (void)
{
	static GType tuba_views_admin_page_accounts_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_views_admin_page_accounts_type_id__once)) {
		GType tuba_views_admin_page_accounts_type_id;
		tuba_views_admin_page_accounts_type_id = tuba_views_admin_page_accounts_get_type_once ();
		g_once_init_leave_pointer (&tuba_views_admin_page_accounts_type_id__once, tuba_views_admin_page_accounts_type_id);
	}
	return tuba_views_admin_page_accounts_type_id__once;
}

static void
_vala_array_destroy (gpointer array,
                     gssize array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		gssize i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gssize array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}

